const express = require('express');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const path = require('path');
const crypto = require('crypto');
const { sendMail, UserContacUs } = require('./mailfunction.js');
const { app_name, app_logo,currentTime } = require('./site_config');

const initController = () => {
    router.get('/user_contact_us', async (req, res) => {
        try {
            const { name, email, message } = req.query;
            // Check if required fields are provided
            if (!name || !email || !message) {
                return res.status(400).json({ success: false, msg: languageMessages.allFieldsRequired[0] });
            }
            // Add user details to the database
            const insertQuery = 'INSERT INTO contact_us_master (name, email, message, createtime, updatetime) VALUES (?, ?, ?, ?, ?)';
            const insertResults = await queryAsync(insertQuery, [name, email, message, currentTime, currentTime]);

            // Select admin details
            const selectAdminQuery = 'SELECT name, email FROM user_master WHERE delete_flag=0 and user_type=0';
            const adminDetails = await queryAsync(selectAdminQuery, []);

            // Send email notification to admin
            const fromName = app_name;
            const subject = 'Contact Us';
            const mailContent = `
                <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#333333; margin-top:0">Hello ${adminDetails[0].name},</p>
                <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#333333; margin-top:0">${name} has contact you with the following details:</p>
                <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#333333; margin-top:0">Name: ${name}</p>
                <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#333333; margin-top:0">Email: ${email}</p>
                <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#333333; margin-top:0">Message: ${message}</p>
            `;
            const mailBody = UserContacUs({ email: adminDetails[0].email, fromName, subject, mailContent, app_logo, name });
            sendMail(adminDetails[0].email, fromName, subject, mailBody)
                .then(response => {
                    console.log('Email response:', response);
                    return res.status(200).json({ success: true, msg: languageMessages.userContactSuccessfully[0]});
                });

            return res.status(200).json({ success: true, msg: languageMessages.userContactSuccessfully[0]});
        } catch (error) {
            console.error('Error handling request:', error);
            return res.status(500).json({ success: false, msg: languageMessages.erroruserContact[0], error: error });
        }
    });

    return router;
};


// Helper function to execute queries with async/await
function queryAsync(query, values) {
    return new Promise((resolve, reject) => {
        connection.query(query, values, (error, results) => {
            if (error) {
                reject(error);
            } else {
                resolve(results);
            }
        });
    });
}

module.exports = initController;
