const express = require('express');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const moment = require('moment-timezone');

const initController = () => {
    router.get('/re_post', async (req, res) => {
        try {
            const encodedpostId = req.query.post_id;
            const currentTime= moment.tz('America/New_York').format('YYYY-MM-DD HH:mm:ss');

            // Fetch the original post
            const selectPostQuery = `
                SELECT 
                    * 
                FROM 
                    post_master 
                WHERE 
                    post_id = ?
            `;
            connection.query(selectPostQuery, [encodedpostId], (postError, postResult) => {
                if (postError) {
                    console.error('Error executing MySQL query:', postError);
                    return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], error: postError });
                }
                if (postResult.length === 0) {
                    return res.status(404).json({ success: false, msg: 'Post not found or deleted' });
                }

                const originalPost = postResult[0];

                // Fetch all images associated with the original post
                const selectImageQuery = `
                    SELECT 
                        * 
                    FROM 
                        post_image_master 
                    WHERE 
                        post_id = ?
                `;
                connection.query(selectImageQuery, [encodedpostId], (imageError, postImageResult) => {
                    if (imageError) {
                        console.error('Error executing MySQL query:', imageError);
                        return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], error: imageError });
                    }

                    // // Check if any images are found
                    // if (postImageResult.length === 0) {
                    //     return res.status(404).json({ success: false, msg: 'Images not found for the post' });
                    // }

                    // Insert the modified post data as a new post
                    const newPost = { ...originalPost };
                    delete newPost.post_id;
                    newPost.delete_flag = 0;
                    newPost.permanent_delete_flag = 0;
                    newPost.createtime = currentTime;
                    newPost.updatetime = currentTime;

                    connection.query('INSERT INTO post_master SET ?', newPost, (insertError, insertResult) => {
                        if (insertError) {
                            console.error('Error inserting new post:', insertError);
                            return res.status(500).json({ success: false, msg: languageMessages.errorrePost[0], error: insertError });
                        }

                        const newPostId = insertResult.insertId;

                        // Insert each image with the new post ID
                        const imageInsertQueries = postImageResult.map(image => {
                            image.post_id = newPostId;
                            delete image.post_image_id; // Remove primary key from the insert data
                            return new Promise((resolve, reject) => {
                                connection.query('INSERT INTO post_image_master SET ?', image, (imageInsertError, imageInsertResult) => {
                                    if (imageInsertError) {
                                        console.error('Error inserting image:', imageInsertError);
                                        reject(imageInsertError);
                                    } else {
                                        resolve();
                                    }
                                });
                            });
                        });

                        // Execute all image insert queries in parallel
                        Promise.all(imageInsertQueries)
                            .then(() => {
                                // Update the old post's permanent_delete_flag to 1
                                const updatePostQuery = `
                                    UPDATE post_master
                                    SET permanent_delete_flag = 1
                                    WHERE post_id = ?
                                `;
                                connection.query(updatePostQuery, [encodedpostId], (updateError, updateResult) => {
                                    if (updateError) {
                                        console.error('Error updating old post:', updateError);
                                        return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], error: updateError });
                                    }
                                    const record = { success: true, msg: languageMessages.rePostSuccessfully[0], new_post_id: newPostId,post_type: originalPost.post_type };
                                    res.json(record);
                                });
                            })
                            .catch(error => {
                                console.error('Error inserting images:', error);
                                res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], error: error });
                            });
                    });
                });
            });
        } catch (error) {
            console.error('Error in /re_post route:', error);
            res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], error: error });
        }
    });
    return router;
};

module.exports = initController;
