// Import necessary modules
//keywordEditController.js
const express = require('express');
const multer = require('multer');
const crypto = require('crypto');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages'); // Import language messages

// Middleware setup for parsing requests
router.use(express.json());
router.use(express.urlencoded({ extended: true }));

// Multer setup for handling multipart/form-data
const upload = multer();
router.use(upload.none());

// Route to handle editing keywords
const initController = () => {
  router.post('/update_admin_lat_long', async (req, res) => {
    try {
      // Validate inputs
      const manage_id = req.body.manage_id;
      const longitude = req.body.longitude;
      const latitude = req.body.latitude;
      // Update keyword in the database
      const query = 'UPDATE admin_manage_master SET longitude = ?, latitude = ?,updatetime = NOW() WHERE manage_id = ?';
      connection.query(query, [longitude, latitude,manage_id], (error, results) => {
        if (error) {
          console.error('Error updating count:', error);
          return res.status(500).json({ success: false, msg: languageMessages.errorDeleteCountUpdate[0] });
        }
        return res.status(200).json({ success: true, msg: languageMessages.countUpdateSuccessfully[0] });
      });
    } catch (error) {
      console.error('Error updating count:', error);
      return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0],error:error });
    }
  });

  return router;
};

module.exports = initController;
