// Import necessary modules

const express = require('express');

const multer = require('multer');

const path = require('path');

const router = express.Router();

const connection = require('./db');

const languageMessages = require('./language_messages'); // Import language messages

const {currentTime } = require('./site_config');



// Set up Multer for file uploads

const storage = multer.diskStorage({

    destination: function (req, file, cb) {

      cb(null, '../webservice/images'); // Save uploaded files to the 'webservice/images' directory

    },

    filename: function (req, file, cb) {

      const uniqueSuffix = Date.now() + '-' + Math.round(Math.random() * 1E9);

      cb(null, file.fieldname + '-' + uniqueSuffix + path.extname(file.originalname));

    }

  });

  

  const upload = multer({ storage: storage });



// Route to handle adding avatars

const initController = () => {

  router.post('/add_avatar', upload.array('files', 1), async (req, res) => {

    try {

      // Check if files are uploaded

      if (!req.files || req.files.length === 0) {

        return res.status(400).json({ success: false, msg: "No files uploaded." });

      }



      // Extract file names

      const compressedFileNames = req.files.map(file => file.filename);

      

      // Insert file names into the database

      const imageInsertQuery = 'INSERT INTO avatar_master (avatar_image,createtime, updatetime) VALUES ( ?,?,?)';

        const imageInsertPromises = [];

        for (const fileName of compressedFileNames) {

          const promise = new Promise((resolve, reject) => {

            connection.query(imageInsertQuery, [fileName,currentTime,currentTime], (imageInsertError, imageInsertResults) => {

              if (imageInsertError) {

                console.error('Error inserting image:', imageInsertError);

                reject(imageInsertError);

              } else {

                console.log('Image inserted:', fileName);

                resolve(imageInsertResults);

              }

            });

          });

          imageInsertPromises.push(promise);

        }

      // Wait for all insert promises to resolve

      await Promise.all(imageInsertPromises);



      return res.status(200).json({ success: true, msg: languageMessages.msgAvatarCreateSuccess[0] });

    } catch (error) {

      console.error('Error handling request:', error);

      return res.status(500).json({ success: false, msg: languageMessages.msgAvatarCreateError[0] });

    }

  });

  

  return router;

};



module.exports = initController;

