const crypto = require('crypto');
const fs = require('fs');
const multer = require('multer');
const compressing = require('compressing');

// Function to generate a random OTP
function generateRandomOTP(length = 6) {
    let otp = '';
    const chars = '123456789';
    for (let i = 0; i < length; i++) {
        otp += chars.charAt(Math.floor(Math.random() * chars.length));
    }
    return otp;
}

// Function to generate a random string
function generateRandomString(length = 10) {
    const chars = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    let randomString = '';
    for (let i = 0; i < length; i++) {
        randomString += chars.charAt(Math.floor(Math.random() * chars.length));
    }
    return randomString;
}

// Function to check if user account is active or not
async function checkAccountActivateDeactivate(user_id) {
    // Include necessary database configuration and connection
    // Perform the database query to check the active status of the user
    // Return the active status (e.g., 'activate' or 'deactivate')
}

// Function to safely encode data to JSON
function safeJsonEncode(value) {
    return JSON.stringify(value, null, 4);
}

// Function to safely decode JSON data
function safeJsonDecode(data) {
    return JSON.parse(data);
}

// Function to safely encode data
function safeB64Encode(string) {
    return Buffer.from(string).toString('base64')
        .replace(/\+/g, '-')
        .replace(/\//g, '_')
        .replace(/=/g, '');
}

// Function to safely decode data
function safeB64Decode(string) {
    const paddedString = string + '==='.slice((string.length + 3) % 4);
    return Buffer.from(paddedString, 'base64').toString('utf-8');
}

// Helper function to encode user_id
function encodeUserId(id) {
    const encodedId = Buffer.from(String(id)).toString('base64');
    console.log(`Encoded user_id: ${encodedId}`);
    return encodedId;
}
  
// Helper function to decode user_id
function decodeUserId(encodedId) {
    const decodedId = parseInt(Buffer.from(encodedId, 'base64').toString('utf-8'));
    console.log(`Decoded user_id: ${decodedId}`);
    return decodedId;
}


// Function to upload a single file with compression
const uploadSingleFile = async (file, folder_name, file_type) => {
    const storage = multer.diskStorage({
        destination: function (req, file, cb) {
            cb(null, folder_name);
        },
        filename: function (req, file, cb) {
            cb(null, Date.now() + '-' + file.originalname);
        }
    });

    const upload = multer({ storage: storage }).single(file_type);

    return new Promise((resolve, reject) => {
        upload(file, null, async function (err) {
            if (err) {
                reject(err);
            } else {
                const filePath = `${folder_name}/${file.filename}`;
                const compressedFileName = `${Date.now()}_${file.originalname}.zip`;
                const compressedFilePath = `${folder_name}/${compressedFileName}`;
                try {
                    await compressing.zip.compressFile(filePath, compressedFilePath);
                    resolve(compressedFileName);
                } catch (error) {
                    reject(error);
                }
            }
        });
    });
};

// Function to upload multiple files with compression
const uploadMultipleFiles = async (file_arr, folder_name) => {
    const storage = multer.diskStorage({
        destination: function (req, file, cb) {
            cb(null, folder_name);
        },
        filename: function (req, file, cb) {
            cb(null, Date.now() + '-' + file.originalname);
        }
    });

    const upload = multer({ storage: storage }).array('files', file_arr.length);

    return new Promise((resolve, reject) => {
        upload(file_arr, null, async function (err) {
            if (err) {
                reject(err);
            } else {
                const compressedFileNames = [];
                for (const file of file_arr) {
                    const filePath = `${folder_name}/${file.filename}`;
                    const compressedFileName = `${Date.now()}_${file.originalname}.zip`;
                    const compressedFilePath = `${folder_name}/${compressedFileName}`;
                    try {
                        await compressing.zip.compressFile(filePath, compressedFilePath);
                        compressedFileNames.push(compressedFileName);
                    } catch (error) {
                        reject(error);
                    }
                }
                resolve(compressedFileNames);
            }
        });
    });
};

module.exports = {
    generateRandomOTP,
    generateRandomString,
    checkAccountActivateDeactivate,
    safeJsonEncode,
    safeJsonDecode,
    uploadSingleFile,
    uploadMultipleFiles,
    safeB64Encode,
    safeB64Decode,
    encodeUserId,
    decodeUserId
};
