// Import the database connection
//common_function_app.js
const connection = require('./db');
const languageMessages = require('./language_messages');

// Function to get user details
async function getUserDetails(user_id) {
  try {
    const query = 'SELECT user_type, name, email, password, image, mobile, active_flag, notification_status, address,username FROM user_master WHERE user_id = ?';
    return new Promise((resolve, reject) => {
      connection.query(query, [user_id], (error, rows) => {
        if (error) {
          console.error('Error fetching user details:', error);
          reject(error);
        } else {
          resolve(rows.length > 0 ? rows[0] : null);
        }
      });
    });
  } catch (error) {
    console.error('Error in getUserDetails:', error);
    return null;
  }
}

// Import the database connection
//const connection = require('./db');

// Function to get notification status
async function getNotificationStatus(user_id) {
  try {
    const query = 'SELECT user_id FROM user_master WHERE user_id = ? AND delete_flag = 0 AND notification_status = 0';
    const [rows] = await connection.execute(query, [user_id]);
    return rows.length > 0 ? 'yes' : 'no';
  } catch (error) {
    console.error('Error fetching notification status:', error);
    return 'no';
  }
}

// Function to insert notification
async function insertNotification(user_id, other_user_id, action, action_id, action_json, title, title_2, title_3, title_4, message, message_2, message_3, message_4) {
  try {
    const read_status = 0;
    const delete_flag = 0;
    const updatetime = new Date().toISOString();
    const createtime = new Date().toISOString();
    const query = 'INSERT INTO user_notification_message(user_id, other_user_id, action, action_id, action_json, title, title_2, title_3, title_4, message, message_2, message_3, message_4, read_status, delete_flag, createtime, updatetime) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
    await connection.execute(query, [user_id, other_user_id, action, action_id, action_json, title, title_2, title_3, title_4, message, message_2, message_3, message_4, read_status, delete_flag, createtime, updatetime]);
    return 'yes';
  } catch (error) {
    console.error('Error inserting notification:', error);
    return 'no';
  }
}

// Function to get user language id
async function getUserLanguageId(user_id) {
  try {
    const query = 'SELECT language_id FROM user_master WHERE user_id = ?';
    const [rows] = await connection.execute(query, [user_id]);
    return rows.length > 0 ? rows[0].language_id : 0;
  } catch (error) {
    console.error('Error fetching user language id:', error);
    return 0;
  }
}

// Function to get user player id
async function getUserPlayerId(user_id) {
  try {
    const query = 'SELECT player_id FROM user_notification WHERE user_id = ?';
    const [rows] = await connection.execute(query, [user_id]);
    return rows.length > 0 ? rows[0].player_id : 'no';
  } catch (error) {
    console.error('Error fetching user player id:', error);
    return 'no';
  }
}

// Notification all functions here
async function getNotificationArrSingle(user_id, other_user_id, action, action_id, title, title_2, title_3, title_4, message, message_2, message_3, message_4, action_data) {
  try {
    const insertStatus = await insertNotification(user_id, other_user_id, action, action_id, JSON.stringify(action_data), title, title_2, title_3, title_4, message, message_2, message_3, message_4);
    if (insertStatus === 'yes') {
      const notificationStatus = await getNotificationStatus(other_user_id);
      if (notificationStatus === 'yes') {
        const player_id = await getUserPlayerId(other_user_id);
        if (player_id !== 'no') {
          const language_id = await getUserLanguageId(other_user_id);
          let titleToSend = title;
          let messageToSend = message;
          if (language_id === 1) {
            titleToSend = title_2;
            messageToSend = message_2;
          } else if (language_id === 2) {
            titleToSend = title_3;
            messageToSend = message_3;
          } else if (language_id === 3) {
            titleToSend = title_4;
            messageToSend = message_4;
          }
          return {
            player_id: player_id,
            title: titleToSend,
            message: messageToSend,
            action_json: action_data
          };
        }
      }
    }
    return 'NA';
  } catch (error) {
    console.error('Error in getNotificationArrSingle:', error);
    return 'NA';
  }
}


module.exports = {
    getUserDetails,
    getNotificationStatus,
    insertNotification,
    getUserLanguageId,
    getUserPlayerId,
    getNotificationArrSingle
};


