const express = require('express');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const isAuthenticated = require('./isAuthenticated');

const initController = () => {
  router.get('/dashboard', async (req, res) => {
    try {
      const userCountQuery = `
        SELECT COUNT(user_id) AS user_count 
        FROM user_master 
        WHERE delete_flag = 0 AND user_type = 1 AND profile_complete = 1
      `;

      connection.query(userCountQuery, (error, [userCheckResults]) => {
        if (error) {
          console.error('Error executing MySQL query:', error);
          return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }

        const userCount = userCheckResults ? userCheckResults.user_count : 0;

        const VuserCountQuery = `
          SELECT COUNT(user_id) AS vip_user_count 
          FROM user_master 
          WHERE delete_flag = 0 AND user_type = 2 AND role = 1
        `;

        connection.query(VuserCountQuery, (error, [VuserCheckResults]) => {
          if (error) {
            console.error('Error executing MySQL query:', error);
            return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
          }

          const VIPuserCount = VuserCheckResults ? VuserCheckResults.vip_user_count : 0;

          const VAuserCountQuery = `
            SELECT COUNT(user_id) AS admin_user_count 
            FROM user_master 
            WHERE delete_flag = 0 AND user_type = 2 AND role = 0
          `;

          connection.query(VAuserCountQuery, (error, [VAuserCheckResults]) => {
            if (error) {
              console.error('Error executing MySQL query:', error);
              return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
            }

            const AdminuserCount = VAuserCheckResults ? VAuserCheckResults.admin_user_count : 0;

            const TopPostCountQuery = `
              SELECT COUNT(post_id) AS top_post_count 
              FROM post_master 
              WHERE delete_flag = 0 AND post_type = 0
            `;

            connection.query(TopPostCountQuery, (error, [TopPostCheckResults]) => {
              if (error) {
                console.error('Error executing MySQL query:', error);
                return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
              }

              const TopPosCount = TopPostCheckResults ? TopPostCheckResults.top_post_count : 0;

              const localPostCountQuery = `
                SELECT COUNT(post_id) AS local_post_count 
                FROM post_master 
                WHERE delete_flag = 0 AND post_type = 1
              `;

              connection.query(localPostCountQuery, (error, [localPostCheckResults]) => {
                if (error) {
                  console.error('Error executing MySQL query:', error);
                  return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
                }

                const localPosCount = localPostCheckResults ? localPostCheckResults.local_post_count : 0;

                const ContactUsCountQuery = `
                  SELECT COUNT(contact_id) AS contact_us_count 
                  FROM contact_us_master 
                  WHERE delete_flag = 0
                `;

                connection.query(ContactUsCountQuery, (error, [ContactUsCheckResults]) => {
                  if (error) {
                    console.error('Error executing MySQL query:', error);
                    return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
                  }

                  const ContactUsCount = ContactUsCheckResults ? ContactUsCheckResults.contact_us_count : 0;

                  const dashboardData = {
                    userCount: userCount,
                    VIPuserCount: VIPuserCount,
                    AdminuserCount: AdminuserCount,
                    TopPosCount: TopPosCount,
                    localPosCount: localPosCount,
                    ContactUsCount: ContactUsCount
                  };

                  const record = { success: true, msg: languageMessages.msgDataFound[0], data: dashboardData };
                  res.json(record);
                });
              });
            });
          });
        });
      });
    } catch (error) {
      console.error('Error executing MySQL query:', error);
      res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
    }
  });

  return router;
};

module.exports = initController;
