const express = require('express');
const multer = require('multer');
const path = require('path');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const { decodeUserId } = require('./common_function');
// Set up Multer for file uploads
const storage = multer.diskStorage({
    destination: function (req, file, cb) {
        cb(null, '../webservice/images'); // Save uploaded files to the 'webservice/images' directory
    },
    filename: function (req, file, cb) {
        const uniqueSuffix = Date.now() + '-' + Math.round(Math.random() * 1E9);
        cb(null, file.fieldname + '-' + uniqueSuffix + path.extname(file.originalname));
    }
});
const upload = multer({ storage: storage });

// Route to handle updating avatars
const initController = () => {
    router.post('/edit_avatar', upload.array('files', 1), async (req, res) => {
        try {
            const encodedAvatarId = req.body.avatar_id;

            const avatarId = decodeUserId(encodedAvatarId);
            // Check if files are uploaded
            if (!req.files || req.files.length === 0) {
                return res.status(200).json({ success: true, msg: languageMessages.avatarUpdatedSuccessfully[0] });
            }
            // Extract file names
            const compressedFileNames = req.files.map(file => file.filename);
            // Update avatar in the database
            const updateQuery = 'UPDATE avatar_master SET avatar_image = ?, updatetime = NOW() WHERE avatar_id = ?';
            await Promise.all(compressedFileNames.map(async (fileName) => {
                await new Promise((resolve, reject) => {
                    connection.query(updateQuery, [fileName, avatarId], (updateError, updateResults) => {
                        if (updateError) {
                            console.error('Error updating image:', updateError);
                            reject(updateError);
                        } else {
                            console.log('Image updated:', fileName);
                            resolve(updateResults);
                        }
                    });
                });
            }));
            return res.status(200).json({ success: true, msg: languageMessages.avatarUpdatedSuccessfully[0] });
        } catch (error) {
            console.error('Error handling request:', error);
            return res.status(500).json({ success: false, msg: languageMessages.errorUpdatedAvatar[0] });
        }
    });
    return router;
};

module.exports = initController;
