// Import necessary modules
const express = require('express');
const multer = require('multer');
const path = require('path');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages'); // Import language messages
const moment = require('moment-timezone');
// Set up Multer for file uploads
const storage = multer.diskStorage({
  destination: function (req, file, cb) {
    cb(null, '../server/webservice/images'); // Save uploaded files to the 'webservice/images' directory
  },
  filename: function (req, file, cb) {
    const uniqueSuffix = Date.now() + '-' + Math.round(Math.random() * 1E9);
    cb(null, file.fieldname + '-' + uniqueSuffix + path.extname(file.originalname));
  }
});
const upload = multer({ storage: storage });
// Route to handle adding keywords
const initController = () => {
  router.post('/edit_post', upload.array('files', 8), async (req, res) => {
    try {
      // Validate inputs
      const { caption, address, latitude, longitude, post_type, post_id } = req.body;
      // let { keyword } = req.body;
      // if (!caption) {
      //   return res.status(400).json({ success: false, msg: languageMessages.allFieldsRequired[0] });
      // }
      // Convert keyword to comma-separated string if it's an array
      // if (Array.isArray(keyword)) {
      //   keyword = keyword.join(',');
      // }
      // Upload images
      const compressedFileNames = req.files.map(file => file.filename);
      const currentTime= moment.tz('America/New_York').format('YYYY-MM-DD HH:mm:ss');
      
      const insertQuery = 'UPDATE `post_master` SET post_type=?,caption=?, location=?, latitude=?, longitude=?,updatetime=? Where post_id=?';
      connection.query(insertQuery, [post_type,caption,address, latitude, longitude,currentTime,post_id], (insertError, insertResults) => {
        if (insertError) {
          console.error('Error update post:', insertError);
          return res.status(500).json({ success: false, msg: languageMessages.msgPostUpdateError[0] });
        }
        // Insert image file names into the databasecreatetime, updatetime
        if (req.files.length !== 0) {
          const imageInsertQuery = 'INSERT INTO post_image_master (post_id, image,createtime, updatetime) VALUES (?, ?,NOW(), NOW())';
          const imageInsertPromises = [];
          for (const fileName of compressedFileNames) {
            const promise = new Promise((resolve, reject) => {
              connection.query(imageInsertQuery, [post_id, fileName], (imageInsertError, imageInsertResults) => {
                if (imageInsertError) {
                  console.error('Error inserting image:', imageInsertError);
                  reject(imageInsertError);
                } else {
                  console.log('Image inserted:', fileName);
                  resolve(imageInsertResults);
                }
              });
            });
            imageInsertPromises.push(promise);
          }
          Promise.all(imageInsertPromises)
            .then(() => {
              return res.status(200).json({ success: true, msg: languageMessages.msgPostUpdateSuccess[0] });
            })
            .catch(error => {
              console.error('Error inserting images:', error);
              return res.status(500).json({ success: false, msg: languageMessages.msgPostCreateError[0] });
            });
        } else {
          // Handle case when no images are uploaded
          return res.status(200).json({ success: true, msg: languageMessages.msgPostUpdateSuccess[0],post_type:post_type });
        }
      });
    } catch (error) {
      console.error('Error handling request:', error);
      return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
    }
  });
  return router;
};
module.exports = initController;
