const express = require('express');
const crypto = require('crypto');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages'); // Import language messages
const { sendMail, mailBodyForgotPasswordData } = require('./mailfunction.js');
const { app_name, app_logo,base_admin_url } = require('./site_config');
const uniqid = require('uniqid');

// Middleware for parsing request bodies
router.use(express.json());
router.use(express.urlencoded({ extended: true }));

const initController = () => {
    router.post('/forgot_password', async (req, res) => {
        const { email } = req.body;
        try {
            if (!email) {
                return res.json({ success: false, msg: languageMessages.allFieldsRequired, data: {} });
            }
            
            connection.query('SELECT user_id, user_type, name,username FROM user_master WHERE delete_flag = 0 AND email = ? AND user_type IN(0,2) and role=0', [email], async (error, results, fields) => {
                if (error) {
                    console.error(error);
                    return res.status(500).json({ success: false, msg: languageMessages.errorforgotPassword[0] });
                }
                
                if (!results || results.length === 0) {
                    return res.json({ success: false, msg: languageMessages.errorforgotPassword[0], data: {} });
                }
                
                const fromName = app_name;

                const subject = 'Forgot Password';
                const uniqcode = uniqid(); // Generate unique identifier
                const md5Hash = crypto.createHash('md5').update(uniqcode).digest('hex');
                const resetPassLink = `${base_admin_url}reset_password.html?uniqcode=${md5Hash}`;
                const mailContent = `
                Recently a request was submitted to reset a password for your account. If this was a mistake, just ignore this email and nothing will happen.
                To reset your password, visit the following link:
                <a href="${resetPassLink}" style="float: unset; width: 25%; display: block; margin: 26px auto 0; background:#f94001; text-align: center; vertical-align: middle; user-select: none; border: 1px solid transparent; padding: .375rem .75rem; font-size: .875rem; line-height: 1.5; border-radius: .25rem; transition: color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out; color: #fff;text-decoration: unset;">Reset Password</a>
                `;

                // Insert query to store forgot password request
                connection.query('INSERT INTO forgot_password_master (user_id, user_type, email, forgot_pass_identity, active_flag, createtime, updatetime) VALUES (?, ?, ?, ?, ?, NOW(), NOW())', [results[0].user_id, results[0].user_type, email, md5Hash, 0], (error, insertResults, fields) => {
                if (error) {
                    console.error('Error inserting forgot password request:', error);
                    return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
                }
                let mailBody;
                if (results[0].user_type === 2) {
                    mailBody = mailBodyForgotPasswordData({ email, fromName, subject, mailContent, app_logo, name: results[0].username });
                } else {
                    mailBody = mailBodyForgotPasswordData({ email, fromName, subject, mailContent, app_logo, name: results[0].name });
                }

                

                // Call sendMail function
                sendMail(email, fromName, subject, mailBody)
                    .then(response => {
                        console.log('Email response:', response);
                    })
                    .catch(error => {
                        console.error('Error sending email:', error);
                    });
               
                return res.json({ success: true, msg: languageMessages.forgotPasswordSuccessfully[0] });
            });
        });
        } catch (error) {
            console.error(error);
            return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], data: {} });
        }
    });
    
    return router;
};

module.exports = initController;
