const express = require('express');

const router = express.Router();

const connection = require('./db');

const languageMessages = require('./language_messages');
const { getUserDetails } = require('./common_function_app');
const {encodeUserId} = require('./common_function');

// Function to format date

function formatDate(dateString) {
  const date = new Date(dateString);
  const options = { day: '2-digit', month: '2-digit', year: 'numeric', hour: '2-digit', minute: '2-digit', hour12: false };
  const formattedDate = date.toLocaleString('en-US', options);
  return formattedDate;
}
const initController = () => {
  router.get('/get_user_contactus', async (req, res) => {
    try {
      const userQuery = `
      SELECT contact_id, user_id, name, message, email, status, createtime, reply_datetime FROM contact_us_master WHERE delete_flag=0 ORDER BY contact_id DESC`;

      connection.query(userQuery, async (error, userResults) => {
        if (error) {
          console.error('Error executing MySQL query:', error);
          return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }

        const userDetailsPromises = userResults.map(async (contact) => {
          const userDetails = await getUserDetails(contact.user_id);
          return userDetails ? userDetails.user_type : 1; // Assuming user_type is stored in 'user_type' field
        });

        const userDetails = await Promise.all(userDetailsPromises);
        
        const users = userResults.map((user, index) => {
          const userType = userDetails[index];
          const userTypeLabel = userType === 1 ? '<span class="badge rounded-pill bg-info inv-badge">Guest User</span>' : '<span class="badge rounded-pill bg-info inv-badge">VIP User</span>';

          return {
            ...user,
            sr_no: index + 1,
            reply_status: user.status === 1 ? '<span class="badge rounded-pill bg-success inv-badge">Replied</span>' : '<span class="badge rounded-pill bg-warning inv-badge">Pending</span>',
            createtime: formatDate(user.createtime),
            reply_datetime: user.reply_datetime ? formatDate(user.reply_datetime) : 'NA',
            action_html: `<div class="btn-group">
                  <a class="dropdown-item edit-btn" href="send_reply.html?id=${encodeUserId(user.contact_id)}"><i class="fa fa-reply"></i></a>
                  <a class="dropdown-item edit-btn" data-id="${encodeUserId(user.contact_id)} "onclick="viewAdminPost(this)"><i class="fa fa-eye"></i></a>
                  <a class="dropdown-item edit-btn" onclick="deleteContactUs(${(user.contact_id)})"><i class="fa fa-trash"></i></a>
            </div>`,
            user_type: userTypeLabel
          };
        });

        const record = { success: true, msg: languageMessages.msgDataFound[0], data: { users } };
        res.json(record);
      });
    } catch (error) {
      console.error('Error executing MySQL query:', error);
      res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
    }
  });

  return router;
};

module.exports = initController;


