//get_contact_user_detail.js
const express = require('express');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const { decodeUserId } = require('./common_function');

function formatDate(dateString) {
  const date = new Date(dateString);
  const options = { 
    day: '2-digit', 
    month: '2-digit', 
    year: 'numeric', 
    hour: '2-digit', 
    minute: '2-digit', 
    hour12: false // Set to false to display time in 24-hour format
  };

  // Get current date
  const today = new Date();

  // Check if the date is today
  if (date.toDateString() === today.toDateString()) {
      return `Today at ${date.getHours().toString().padStart(2, '0')}:${date.getMinutes().toString().padStart(2, '0')}`;
  }

  // Check if the date is within the same month and year
  if (date.getMonth() === today.getMonth() && date.getFullYear() === today.getFullYear()) {
      const dayDifference = today.getDate() - date.getDate();
      return `${date.toLocaleDateString('en-US', options)} (${dayDifference} day${dayDifference !== 1 ? 's' : ''} ago)`;
  }

  // Check if the date is within the same year
  if (date.getFullYear() === today.getFullYear()) {
      const monthDifference = today.getMonth() - date.getMonth();
      return `${date.toLocaleDateString('en-US', options)} (${monthDifference} month${monthDifference !== 1 ? 's' : ''} ago)`;
  }

  // If the date is not within the same year, return the full formatted date
  return date.toLocaleString('en-US', options);
}
const initController = () => {
  router.get('/get_contact_user_detail', async (req, res) => {
    try {
      const contact_id = req.query.contact_id;
      const decodecontactid = decodeUserId(contact_id);

      const userQuery = 'SELECT contact_id, name, email, message, status, reply_datetime, createtime FROM contact_us_master WHERE contact_id = ? AND delete_flag = 0'; // Update the SQL query to filter by contact_id
      connection.query(userQuery, [decodecontactid], (error, detailResult) => {
        if (error) {
          console.error('Error executing MySQL query:', error);
          return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }

        // Check if any contact detail is found
        if (detailResult.length === 0) {
          return res.status(404).json({ success: false, msg: 'Data not found' });
        }

        const contact_detail = detailResult[0]; // Get the first (and only) contact detail from the result

        // Format status and datetime
        const reply_status = contact_detail.status === 1 ? '<span class="badge rounded-pill bg-success inv-badge">Replied</span>' : '<span class="badge rounded-pill bg-warning inv-badge">Pending</span>';
        const createtime = formatDate(contact_detail.createtime);
        const reply_datetime = contact_detail.reply_datetime ? formatDate(contact_detail.reply_datetime) : 'NA';

        contact_detail.reply_status = reply_status;
        contact_detail.createtime = createtime;
        contact_detail.reply_datetime = reply_datetime;

        // Prepare response
        const record = { success: true, msg: 'Data found', data: contact_detail };
        res.json(record);
      });
    } catch (error) {
      console.error('Error executing MySQL query:', error);
      res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
    }
  });

  return router;
};

module.exports = initController;
