const express = require('express');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const { decodeUserId } = require('./common_function');
const {currentTime } = require('./site_config');

function formatDate(dateString) {
  const date = new Date(dateString);
  const options = { day: '2-digit', month: '2-digit', year: 'numeric', hour: '2-digit', minute: '2-digit', hour12: true};
  // Calculate the difference in days
  const today = new Date();
  const timeDifference = Math.abs(today.getTime() - date.getTime());
  const dayDifference = Math.ceil(timeDifference / (1000 * 3600 * 24));
  const daysAgo = `${dayDifference} day${dayDifference !== 1 ? 's' : ''} ago`;

  const formattedDate = date.toLocaleString('en-US', options);
  return `${formattedDate} (${daysAgo})`;
}

const initController = () => {
    router.get('/get_edit_post_detail', async (req, res) => {
        try {
            const encodedpostId = req.query.post_id;
            // Decode the encoded post_id
            const postId = decodeUserId(encodedpostId); // Assuming decodeUserId is correctly implemented

            const userQuery = `
                SELECT 
                    p.post_id, p.user_id, p.caption, p.location,p.latitude,p.longitude, p.createtime, p.keyword_ids,p.post_type,GROUP_CONCAT(k.keyword) AS keyword_names, u.username
                FROM 
                    post_master p
                JOIN 
                    user_master u ON u.user_id = p.user_id
                LEFT JOIN
                    keyword_master k ON FIND_IN_SET(k.keyword_id, p.keyword_ids)
                LEFT JOIN
                    post_like_master pl ON p.post_id = pl.post_id
                WHERE 
                    p.post_id = ?
                GROUP BY
                    p.post_id
            `;

            connection.query(userQuery, [encodedpostId], (error, postResult) => {
                if (error) {
                    console.error('Error executing MySQL query:', error);
                    return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
                }
                // Check if any post is found
                if (postResult.length === 0) {
                    return res.status(404).json({ success: false, msg: 'Post not found' });
                }

                const post_detail = postResult[0]; // Get the first (and only) post from the result
                post_detail.formatted_createtime = formatDate(post_detail.createtime);

                const record = { success: true, msg: languageMessages.msgDataFound[0], data: { post_detail } };
                res.json(record);
            });
        } catch (error) {
            console.error('Error in get_local_post_detail:', error);
            res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }
    });
    return router;
};

module.exports = initController;
