//getkeywordnamebyid.js

const express = require('express');

const router = express.Router();

const connection = require('./db');

const languageMessages = require('./language_messages');

const { decodeUserId } = require('./common_function');

// function formatDate(dateString) {
//   const date = new Date(dateString);
//   const options = { day: '2-digit', month: '2-digit', year: 'numeric', hour: '2-digit', minute: '2-digit', hour12: true,timeZone: 'America/New_York' };
//   // Calculate the difference in days
//   const today = new Date();
//   const timeDifference = Math.abs(today.getTime() - date.getTime());
//   const dayDifference = Math.ceil(timeDifference / (1000 * 3600 * 24));
//   const daysAgo = `${dayDifference} day${dayDifference !== 1 ? 's' : ''} ago`;

//   const formattedDate = date.toLocaleString('en-US', options);
//   return `${formattedDate} (${daysAgo})`;
// }

function formatDate(dateString) {
  const date = new Date(dateString);
  const options = { 
    day: '2-digit', 
    month: '2-digit', 
    year: 'numeric', 
    hour: '2-digit', 
    minute: '2-digit', 
    hour12: false // Set to false to display time in 24-hour format
  };

  // Get current date
  const today = new Date();

  // Check if the date is today
  if (date.toDateString() === today.toDateString()) {
      return `Today at ${date.getHours().toString().padStart(2, '0')}:${date.getMinutes().toString().padStart(2, '0')}`;
  }

  // Check if the date is within the same month and year
  if (date.getMonth() === today.getMonth() && date.getFullYear() === today.getFullYear()) {
      const dayDifference = today.getDate() - date.getDate();
      return `${date.toLocaleDateString('en-US', options)} (${dayDifference} day${dayDifference !== 1 ? 's' : ''} ago)`;
  }

  // Check if the date is within the same year
  if (date.getFullYear() === today.getFullYear()) {
      const monthDifference = today.getMonth() - date.getMonth();
      return `${date.toLocaleDateString('en-US', options)} (${monthDifference} month${monthDifference !== 1 ? 's' : ''} ago)`;
  }

  // If the date is not within the same year, return the full formatted date
  return date.toLocaleString('en-US', options);
}


const initController = () => {

    router.get('/get_guest_user_detail', async (req, res) => {

        try {
            const encodeduserId = req.query.user_id;
            // Decode the encoded user_id
            const userId = decodeUserId(encodeduserId);
            const userQuery = `
              SELECT 
                u.user_id, u.email, u.mobile, u.username, u.image, u.active_flag, u.createtime, u.avatar_id, u.currect_location_permanent, u.about,u.address, a.avatar_image,u.password_new,u.latitude,u.longitude,u.note_by_admin
              FROM 
                user_master u
                LEFT JOIN 
                avatar_master a ON u.avatar_id = a.avatar_id
              WHERE 
                u.delete_flag = 0 AND u.user_type = 1 AND u.profile_complete = 1 AND u.user_id = ?
            `; // Update the SQL query to filter by user_id
      
            connection.query(userQuery, [userId], (error, keywordResult) => {
              if (error) {
                console.error('Error executing MySQL query:', error);
                return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
              }
              // Check if any keyword is found
              if (keywordResult.length === 0) {
                return res.status(404).json({ success: false, msg: 'Keyword not found' });
              }
      
              const user_detail = keywordResult[0]; // Get the first (and only) keyword from the result
      
              // Conditionally set location based on currect_location_permanent value
              const location = user_detail.currect_location_permanent === 0 ? 'No' : 'Yes';
      
              // Add location field to user_detail
              user_detail.location_permanent = location;

              user_detail.formatted_createtime = formatDate(user_detail.createtime);

              const address_locate = user_detail.latitude ? 
              `<a href="http://www.google.com/maps/place/${user_detail.latitude},${user_detail.longitude}" target="_blank">
                  <span style="color:red;">${user_detail.latitude},${user_detail.longitude}</span>
              </a>
              <p>${user_detail.address}</p>` :
              'NA';
              user_detail.address_locate = address_locate;
      
              const record = { success: true, msg: languageMessages.msgDataFound[0], data: { user_detail } };
      
              res.json(record);
            });
          } catch (error) {
            console.error('Error executing MySQL query:', error);
            res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
          }
        });
        return router;
      };
      
      module.exports = initController;