const express = require('express');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const { decodeUserId } = require('./common_function');

function formatDate(dateString) {
  const date = new Date(dateString);
  const options = { 
    day: '2-digit', 
    month: '2-digit', 
    year: 'numeric', 
    hour: '2-digit', 
    minute: '2-digit', 
    hour12: false // Set to false to display time in 24-hour format
  };

  // Get current date
  const today = new Date();

  // Check if the date is today
  if (date.toDateString() === today.toDateString()) {
      return `Today at ${date.getHours().toString().padStart(2, '0')}:${date.getMinutes().toString().padStart(2, '0')}`;
  }

  // Check if the date is within the same month and year
  if (date.getMonth() === today.getMonth() && date.getFullYear() === today.getFullYear()) {
      const dayDifference = today.getDate() - date.getDate();
      return `${date.toLocaleDateString('en-US', options)} (${dayDifference} day${dayDifference !== 1 ? 's' : ''} ago)`;
  }

  // Check if the date is within the same year
  if (date.getFullYear() === today.getFullYear()) {
      const monthDifference = today.getMonth() - date.getMonth();
      return `${date.toLocaleDateString('en-US', options)} (${monthDifference} month${monthDifference !== 1 ? 's' : ''} ago)`;
  }

  // If the date is not within the same year, return the full formatted date
  return date.toLocaleString('en-US', options);
}


const initController = () => {
    router.get('/get_post_detail', async (req, res) => {
        try {
            const encodedpostId = req.query.post_id;
            // Decode the encoded post_id
            const postId = (encodedpostId);
            const userQuery = `
                SELECT 
                p.post_id, p.user_id, p.caption, p.location,p.latitude,p.longitude, p.createtime, p.keyword_ids,p.post_type,GROUP_CONCAT(k.keyword) AS keyword_names, u.username,
                COUNT(CASE WHEN pl.type = 0 THEN 1 ELSE NULL END) AS like_count,
                COUNT(CASE WHEN pl.type = 1 THEN 1 ELSE NULL END) AS dislike_count
              FROM 
                post_master p
              JOIN 
                user_master u ON u.user_id = p.user_id
              LEFT JOIN
                keyword_master k ON FIND_IN_SET(k.keyword_id, p.keyword_ids)
              LEFT JOIN
                post_like_master pl ON p.post_id = pl.post_id
              WHERE 
                p.post_id = ?
              GROUP BY
                p.post_id
            `; // Updated SQL query to fetch keyword names
      
            connection.query(userQuery, [postId], (error, postResult) => {
                if (error) {
                    console.error('Error executing MySQL query:', error);
                    return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
                }
                // Check if any post is found
                if (postResult.length === 0) {
                    return res.status(404).json({ success: false, msg: 'Post not found' });
                }

                const post_detail = postResult[0]; // Get the first (and only) post from the result
                post_detail.formatted_createtime = formatDate(post_detail.createtime);

                const address_locate = `<a href="http://www.google.com/maps/place/${post_detail.latitude},${post_detail.longitude}" target="_blank"><span style="color:red;">${post_detail.latitude},${post_detail.longitude}</span>, <span style="color: black;">${post_detail.location}</span></a>`;

                post_detail.location = address_locate;

                const caption = post_detail.caption ? post_detail.caption:'NA';
                post_detail.caption = caption;

                const record = { success: true, msg: languageMessages.msgDataFound[0], data: { post_detail } };

                res.json(record);
            });
        } catch (error) {
            console.error('Error in get_local_post_detail:', error);
            res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }
    });
    return router;
};

module.exports = initController;
