const express = require('express');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const { decodeUserId } = require('./common_function');
function formatDate(dateString) {
  const date = new Date(dateString);
  const options = { day: '2-digit', month: '2-digit', year: 'numeric', hour: '2-digit', minute: '2-digit', hour12: true };
  const formattedDate = date.toLocaleString('en-US', options);
  return formattedDate;
}

const initController = () => {
    router.get('/get_post_dislike', async (req, res) => {
        try {
            const encodedPostId = req.query.post_id;
            // Decode the encoded post_id
            const postId = decodeUserId(encodedPostId);
            const userQuery = `
              SELECT 
                l.post_like_id, l.user_id, l.createtime, u.username, u.avatar_id, a.avatar_image
              FROM 
                post_like_master l
              JOIN 
                user_master u ON u.user_id = l.user_id
              LEFT JOIN
                avatar_master a ON a.avatar_id = u.avatar_id
              WHERE 
                l.delete_flag = 0 AND l.type = 1 AND l.post_id = ?
              ORDER BY l.post_like_id DESC
            `;
      
            const postResult = await new Promise((resolve, reject) => {
                connection.query(userQuery, [postId], (error, results) => {
                    if (error) {
                        reject(error);
                    } else {
                        resolve(results);
                    }
                });
            });


           let post_dislikes;
            // Check if any posts are found
            if (postResult.length === 0) {
               post_dislikes = []; 
              const record = { success: true, msg: languageMessages.msgDataFound[0], data: { post_dislikes } };
              return res.json(record);
            }

            post_dislikes = postResult.map((post_like, index) => ({
                ...post_like,
                sr_no: index + 1, // Calculate serial number dynamically
                image_html: `<img  width="50px" src="../images/${post_like.avatar_image}" class="rounded-circle circle-border m-b-md img-fix img-responsive" name="profile_image" id="previewholder" style="width: 70px; height: 70px;" onerror="this.src='assets/images/placeholder.png';">`,
                createtime: formatDate(post_like.createtime),
            }));

            const record = { success: true, msg: languageMessages.msgDataFound[0], data: { post_dislikes } };

            res.json(record);
        } catch (error) {
            console.error('Error in get_post_like:', error);
            res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }
    });
    return router;
};

module.exports = initController;
