const express = require('express');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const { decodeUserId } = require('./common_function');
function formatDate(dateString) {
    const date = new Date(dateString);
    const options = { day: '2-digit', month: '2-digit', year: 'numeric', hour: '2-digit', minute: '2-digit', hour12: true };
    const formattedDate = date.toLocaleString('en-US', options);
    return formattedDate;
  }
const initController = () => {
    router.get('/get_post_images', async (req, res) => {
        try {
            const encodedPostId = req.query.post_id;
            // Decode the encoded post_id
            const postId = (encodedPostId);
            const userQuery = `SELECT post_image_id , image, createtime FROM post_image_master WHERE 
                delete_flag = 0  AND post_id = ? ORDER BY post_image_id  DESC`;
            const postResult = await new Promise((resolve, reject) => {
                connection.query(userQuery, [postId], (error, results) => {
                    if (error) {
                        reject(error);
                    } else {
                        resolve(results);
                    }
                });
            });


           let post_images;
            // Check if any posts are found
            if (postResult.length === 0) {
               post_images = []; 
              const record = { success: true, msg: languageMessages.msgDataFound[0], data: { post_images } };
              return res.json(record);
            }

            post_images = postResult.map((post_image, index) => ({
                ...post_image,
                sr_no: index + 1, // Calculate serial number dynamically
                image_html: `<img  width="50px" src="../images/${post_image.image}" class="rounded-circle circle-border m-b-md img-fix img-responsive" name="profile_image" id="previewholder" style="width: 70px; height: 70px;" onerror="this.src='assets/images/placeholder.png';">`,
                createtime: formatDate(post_image.createtime),
            }));

            const record = { success: true, msg: languageMessages.msgDataFound[0], data: { post_images } };

            res.json(record);
        } catch (error) {
            console.error('Error in get_post_image:', error);
            res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }
    });
    return router;
};

module.exports = initController;
