// Import necessary modules
// keywordEditController.js
const express = require('express');
const multer = require('multer');
const crypto = require('crypto');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages'); // Import language messages
const { encodeUserId } = require('./common_function');
const { getUserDetails } = require('./common_function_app');
// console.log('login');
router.use(express.json());
router.use(express.urlencoded({ extended: true }));
const upload = multer();
router.use(upload.none());
// Route to handle editing keywords
function formatDate(dateString) {
    const date = new Date(dateString);
    const options = { year: 'numeric', month: '2-digit', day: '2-digit', hour: '2-digit', minute: '2-digit', hour12: false };
    return date.toLocaleString('en-US', options);
}

const initController = () => {
    router.post('/get_post_report', async (req, res) => {
        try {
            // Validate keyword and keyword_id
            const s_date = req.body.s_date;
            const e_date = req.body.e_date;
            const post_type = req.body.post_type;

            // Update keyword in the database
            const query = `
            SELECT post_id, user_id, caption, location, createtime, created_by,post_type FROM post_master WHERE delete_flag = 0 AND post_type = ? AND DATE(createtime) BETWEEN ? AND ? order by post_id desc`; // Assuming 'keyword_master' is your table name
            connection.query(query, [post_type, s_date, e_date], async (error, results) => {
                if (error) {
                    console.error('Error executing MySQL query:', error);
                    return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], error: error.message });
                }

                const userDetailsPromises = results.map(async (user) => {
                    try {
                        const userDetails = await getUserDetails(user.user_id);
                        return userDetails ? userDetails.username : null; // Assuming username is stored in 'name' field
                    } catch (getUserDetailsError) {
                        console.error('Error fetching user details:', getUserDetailsError);
                        return null;
                    }
                });

                const userDetails = await Promise.all(userDetailsPromises);

                const post_arr = results.map((user, index) => ({
                    ...user,
                    sr_no: index + 1,
                    createtime: formatDate(user.createtime),
                    action_html: `<div class="btn-group">
                        <button type="button" class="btn btn-primary dropdown-toggle float-button-light" id="primary-dropdown-outline" data-toggle="dropdown" aria-expanded="false">
                            Action
                        </button>
                        <ul class="dropdown-menu dropdown-menu-primary" style="margin: 2px -56px 0;" aria-labelledby="primary-dropdown" role="menu">
                            ${user.post_type == 1 ? `<li><a class="dropdown-item" href="view_top_post.html?id=${encodeUserId(user.post_id)}"><i class="fa fa-eye"></i> View</a></li>` : `<li><a class="dropdown-item" href="view_local_post.html?id=${encodeUserId(user.post_id)}"><i class="fa fa-eye"></i> View</a></li>`}
                        </ul>
                    </div>`,
                    username: userDetails[index], // Adding username to the user object
                    caption : user.caption ? user.caption:'NA'
                }));

                const record = { success: true, msg: languageMessages.msgDataFound[0], data: { post_arr } };
                res.json(record);
            });
        } catch (error) {
            console.error('Error executing MySQL query:', error);
            res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], error: error.message });
        }
    });
    return router;
};

module.exports = initController;


