// Import necessary modules
// keywordEditController.js
const express = require('express');
const multer = require('multer');
const crypto = require('crypto');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages'); // Import language messages
const { encodeUserId } = require('./common_function');
const { getUserDetails } = require('./common_function_app');
// console.log('login');
router.use(express.json());
router.use(express.urlencoded({ extended: true }));
const upload = multer();
router.use(upload.none());
// Route to handle editing keywords
function formatDate(dateString) {
    const date = new Date(dateString);
    const options = { year: 'numeric', month: '2-digit', day: '2-digit', hour: '2-digit', minute: '2-digit', hour12: false };
    return date.toLocaleString('en-US', options);
}

const initController = () => {
    router.post('/get_reported_post', async (req, res) => {
        try {
            // Validate keyword and keyword_id
            const s_date = req.body.s_date;
            const e_date = req.body.e_date;
            const post_type = req.body.post_type;

            // Update keyword in the database
            const query = `
            SELECT rm.report_id, rm.user_id, rm.post_id, rm.reason, rm.createtime, um.username, pm.caption
            FROM report_master rm
            JOIN user_master um ON rm.user_id = um.user_id
            JOIN post_master pm ON rm.post_id = pm.post_id
            WHERE rm.delete_flag = 0 AND rm.post_type = ? AND DATE(rm.createtime) BETWEEN ? AND ? order by rm.report_id desc`; // Assuming 'keyword_master' is your table name
            connection.query(query, [post_type, s_date, e_date], async (error, results) => {
                if (error) {
                    console.error('Error executing MySQL query:', error);
                    return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], error: error.message });
                }

                const post_arr = results.map((post, index) => ({
                    ...post,
                    sr_no: index + 1,
                    createtime: formatDate(post.createtime),
                    caption : post.caption ? post.caption:'NA'
                    // Any other processing you need to do for each post
                }));

                const record = { success: true, msg: languageMessages.msgDataFound[0], data: { post_arr } };
                res.json(record);
            });
        } catch (error) {
            console.error('Error executing MySQL query:', error);
            res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], error: error.message });
        }
    });
    return router;
};

module.exports = initController;



