const express = require('express');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const { encodeUserId } = require('./common_function');
const { getUserDetails } = require('./common_function_app');
// Function to format date
function formatDate(dateString) {
  const date = new Date(dateString);
  const options = { year: 'numeric', month: '2-digit', day: '2-digit', hour: '2-digit', minute: '2-digit', hour12: false };
  return date.toLocaleString('en-US', options);
}
const initController = () => {
  router.get('/getSubadminDeletedPost', async (req, res) => {
    try {
        const user_id = req.query.userId;

      const userQuery = 'SELECT post_id,user_id,caption,location,updatetime,created_by,post_type,delete_by  FROM post_master WHERE delete_flag = 1 and user_id=?';
      connection.query(userQuery,[user_id], async (error, userResults) => {
        if (error) {
          console.error('Error executing MySQL query:', error);
          return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }
        
        try {
          const userDetailsPromises = userResults.map(async (user) => {
            const userDetails = await getUserDetails(user.user_id);
            return userDetails ? userDetails.username : null; // Assuming username is stored in 'name' field
          });
          const userDetails = await Promise.all(userDetailsPromises);
          const post_arr = userResults.map((user, index) => ({
            ...user,
            sr_no: index + 1,
            createtime: formatDate(user.updatetime),
            deleted_by: user.delete_by === 0 ? 'Owner' : user.delete_by === 1 ? 'Dislike' : user.delete_by === 2 ? 'Day' : user.delete_by === 3 ? 'Admin' : 'Unknown',
            post_type: user.post_type === 0 ? 'Local Post' : 'Top Post',
            username: userDetails[index], // Adding username to the user object
            action_html: `<div class="btn-group">
                <button type="button" class="btn btn-primary dropdown-toggle float-button-light" id="primary-dropdown-outline" data-toggle="dropdown" aria-expanded="false">
                    Action
                </button>
                <ul class="dropdown-menu dropdown-menu-primary" style="margin: 2px -56px 0;" aria-labelledby="primary-dropdown" role="menu">
                    ${user.post_type === 0 ? `<li><a class="dropdown-item" href="view_local_post.html?id=${(user.post_id)}"><i class="fa fa-eye"></i> View</a></li>` : `<li><a class="dropdown-item" href="view_top_post.html?id=${encodeUserId(user.post_id)}"><i class="fa fa-eye"></i> View</a></li>`}
                </ul>

            </div>`,
            caption: user.caption ? user.caption : 'NA',
          }));
          const record = { success: true, msg: languageMessages.msgDataFound[0], data: { post_arr } };
          res.json(record);
        } catch (error) {
          console.error('Error fetching user details:', error);
          res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }
      });
    } catch (error) {
      console.error('Error executing MySQL query:', error);
      res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
    }
  });
  return router;
};
module.exports = initController;
