const express = require('express');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const { decodeUserId } = require('./common_function');

// Function to format date
function formatDate(dateString) {
    const date = new Date(dateString);
    const options = { day: '2-digit', month: '2-digit', year: 'numeric', hour: '2-digit', minute: '2-digit', hour12: false };
    const formattedDate = date.toLocaleString('en-US', options);
    return formattedDate;
  }
  

const initController = () => {
    router.get('/get_user_keyword', async (req, res) => {
        try {
            const encodedUserId = req.query.user_id;
            // Decode the encoded user_id
            const userId = decodeUserId(encodedUserId);
            const query = 'SELECT keyword_id, keyword, createtime FROM keyword_master WHERE delete_flag = 0 and user_id = ?';
            connection.query(query, [userId], async (error, results) => {
                if (error) {
                    console.error('Error executing MySQL query:', error);
                    return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
                }
                try {
                    // Prepare post data with additional details
                    const keywords = results.map((keyword, index) => ({
                        ...keyword,
                        sr_no: index + 1,
                        createtime: formatDate(keyword.createtime),
                        
                    }));
                    const record = { success: true, msg: languageMessages.msgDataFound[0], data: { keywords } };
                    res.json(record);
                } catch (error) {
                    console.error('Error fetching user details:', error);
                    res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
                }
            });
        } catch (error) {
            console.error('Error executing MySQL query:', error);
            res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }
    });
    return router;
};

module.exports = initController;
