const express = require('express');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const { getUserDetails } = require('./common_function_app');
const { decodeUserId, encodeUserId } = require('./common_function');

// Function to format date
function formatDate(dateString) {
    const date = new Date(dateString);
    const options = { day: '2-digit', month: '2-digit', year: 'numeric', hour: '2-digit', minute: '2-digit', hour12: false };
    const formattedDate = date.toLocaleString('en-US', options);
    return formattedDate;
  }
  

const initController = () => {
    router.get('/get_user_top_post', async (req, res) => {
        try {
            const encodedUserId = req.query.user_id;
            // Decode the encoded user_id
            const userId = decodeUserId(encodedUserId);
            const query = 'SELECT post_id, user_id, caption, location,latitude,longitude, createtime FROM post_master WHERE delete_flag = 0 AND post_type = 1 and user_id = ? order by post_id desc';
            connection.query(query, [userId], async (error, results) => {
                if (error) {
                    console.error('Error executing MySQL query:', error);
                    return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
                }
                try {
                    // Fetch user details asynchronously for each post
                    const userDetailsPromises = results.map(async (post) => {
                        const userDetails = await getUserDetails(post.user_id);
                        return userDetails ? userDetails.name : null; // Assuming username is stored in 'name' field
                    });
                    const userDetails = await Promise.all(userDetailsPromises);
                    // Prepare post data with additional details
                    const posts = results.map((post, index) => ({
                        ...post,
                        sr_no: index + 1,
                        createtime: formatDate(post.createtime),
                        action_html: `<div class="btn-group">
                            <button type="button" class="btn btn-primary dropdown-toggle float-button-light" id="primary-dropdown-outline" data-toggle="dropdown" aria-expanded="false">
                                Action
                            </button>
                            <ul class="dropdown-menu dropdown-menu-primary" style="margin: 2px -56px 0;" aria-labelledby="primary-dropdown" role="menu">
                                <li><a class="dropdown-item" href="view_post.php?id=${encodeUserId(post.post_id)}"><i class="fa fa-eye"></i> View</a></li>
                            </ul>
                        </div>`,
                        location: `<a href="http://www.google.com/maps/place/${post.latitude},${post.longitude}" target="_blank"><span style="color:red;">${post.latitude},${post.longitude}</span></a>
                            <p>${post.location}</p>`,
                        username: userDetails[index], // Adding username to the post object
                        caption : post.caption ? post.caption:'NA'
                    }));
                    const record = { success: true, msg: languageMessages.msgDataFound[0], data: { posts } };
                    res.json(record);
                } catch (error) {
                    console.error('Error fetching user details:', error);
                    res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
                }
            });
        } catch (error) {
            console.error('Error executing MySQL query:', error);
            res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }
    });
    return router;
};

module.exports = initController;
