const express = require('express');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const { decodeUserId } = require('./common_function');

function formatDate(dateString) {
  const date = new Date(dateString);
  const options = { 
    day: '2-digit', 
    month: '2-digit', 
    year: 'numeric', 
    hour: '2-digit', 
    minute: '2-digit', 
    hour12: false // Set to false to display time in 24-hour format
  };

  // Get current date
  const today = new Date();

  // Check if the date is today
  if (date.toDateString() === today.toDateString()) {
      return `Today at ${date.getHours().toString().padStart(2, '0')}:${date.getMinutes().toString().padStart(2, '0')}`;
  }

  // Check if the date is within the same month and year
  if (date.getMonth() === today.getMonth() && date.getFullYear() === today.getFullYear()) {
      const dayDifference = today.getDate() - date.getDate();
      return `${date.toLocaleDateString('en-US', options)} (${dayDifference} day${dayDifference !== 1 ? 's' : ''} ago)`;
  }

  // Check if the date is within the same year
  if (date.getFullYear() === today.getFullYear()) {
      const monthDifference = today.getMonth() - date.getMonth();
      return `${date.toLocaleDateString('en-US', options)} (${monthDifference} month${monthDifference !== 1 ? 's' : ''} ago)`;
  }

  // If the date is not within the same year, return the full formatted date
  return date.toLocaleString('en-US', options);
}




const initController = () => {
  router.get('/get_vip_user_detail', async (req, res) => {
    try {
      const encodeduserId = req.query.user_id;
      // Decode the encoded user_id
      const userId = decodeUserId(encodeduserId);
      const userQuery = `
        SELECT 
          u.user_id, u.email, u.mobile, u.username, u.image, u.active_flag, u.createtime, u.avatar_id, u.currect_location_permanent, u.about, u.address, a.avatar_image, u.longitude, u.latitude, u.current_location, u.current_lattitude, u.current_longitude, u.password_new, u.role, u.account_currency, u.account_fund_balance, u.note_by_admin
        FROM 
          user_master u
        LEFT JOIN 
          avatar_master a ON u.avatar_id = a.avatar_id
        WHERE 
          u.delete_flag = 0 AND u.user_type = 2 AND u.user_id = ?
      `; // Update the SQL query to filter by user_id

      connection.query(userQuery, [userId], (error, userResult) => {
        if (error) {
          console.error('Error executing MySQL query:', error);
          return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }
        // Check if any user is found
        if (userResult.length === 0) {
          return res.status(404).json({ success: false, msg: 'User not found' });
        }

        const userDetail = userResult[0]; // Get the first (and only) user from the result

        // Conditionally set location based on currect_location_permanent value
        const location = userDetail.currect_location_permanent === 0 ? 'No' : 'Yes';

        // Add location field to userDetail
        userDetail.location_permanent = location;
        userDetail.formatted_createtime = formatDate(userDetail.createtime);

        const address_new = userDetail.latitude ? 
        `<a href="http://www.google.com/maps/place/${userDetail.latitude},${userDetail.longitude}" target="_blank">
            <span style="color:red;">${userDetail.latitude},${userDetail.longitude}</span>
        </a>
        <p>${userDetail.address}</p>` :
        'NA';
        userDetail.address_new = address_new;

        const current_location_new = userDetail.current_lattitude ? 
        `<a href="http://www.google.com/maps/place/${userDetail.current_lattitude},${userDetail.current_longitude}" target="_blank">
            <span style="color:red;">${userDetail.current_lattitude},${userDetail.current_longitude}</span>
        </a>
        <p>${userDetail.current_location}</p>` :
        'NA';


        userDetail.current_location_new = current_location_new;

        const record = { success: true, msg: languageMessages.msgDataFound[0], data: { user_detail: userDetail } };

        res.json(record);
      });
    } catch (error) {
      console.error('Error executing MySQL query:', error);
      res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
    }
  });
  return router;
};

module.exports = initController;
