// Import necessary modules
// keywordEditController.js
const express = require('express');
const multer = require('multer');
const crypto = require('crypto');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages'); // Import language messages
const { encodeUserId } = require('./common_function');
// console.log('login');
router.use(express.json());
router.use(express.urlencoded({ extended: true }));
const upload = multer();
router.use(upload.none());
// Route to handle editing keywords
function formatDate(dateString) {
    const date = new Date(dateString);
    const options = { day: '2-digit', month: '2-digit', year: 'numeric', hour: '2-digit', minute: '2-digit', hour12: false};
    const formattedDate = date.toLocaleString('en-US', options);
    return formattedDate;
}

const initController = () => {
    router.post('/get_vip_user_report', async (req, res) => {
        try {
            // Validate keyword and keyword_id
            const s_date = req.body.s_date;
            const e_date = req.body.e_date;
            const user_type = req.body.user_type;

            // Update keyword in the database
            const query = `SELECT u.user_id, u.email, u.mobile, u.username, u.image, u.active_flag, u.createtime FROM user_master u WHERE u.delete_flag = 0 AND u.user_type = ? and date(u.createtime) BETWEEN ? and ? order by u.user_id desc`; // Assuming 'keyword_master' is your table name
            connection.query(query, [user_type, s_date, e_date], (error, results) => {
                if (error) {
                    console.error('Error executing MySQL query:', error);
                    return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], error: error.message });
                }

                let users = null; // Initialize users as null
                if (results.length > 0) {
                    users = results.map((user, index) => ({
                        ...user,
                        sr_no: index + 1,
                        status: user.active_flag === 1 ? '<span class="badge rounded-pill bg-success inv-badge">Active</span>' : '<span class="badge rounded-pill bg-danger inv-badge">Deactive</span>',
                        createtime: formatDate(user.createtime), // Assuming formatDate is defined somewhere
                        action_html: `<div class="btn-group">
                        <a class="dropdown-item edit-btn" href="view_vip_user.html?id=${encodeUserId(user.user_id)}"><i class="fa fa-eye"></i></a>
                        </div>`,
                        image_html: `<img  width="50px" src="../server/webservice/images/${user.image}" class="rounded-circle circle-border m-b-md img-fix img-responsive" name="profile_image" id="previewholder" style="width: 70px; height: 70px;" onerror="this.src='assets/images/placeholder.png';">`,
                         email : user.email ? 
                        user.email :
                        'NA'
                    }));
                }

                const record = { success: true, msg: languageMessages.msgDataFound[0], data: { users } };
                res.json(record);
            });
        } catch (error) {
            console.error('Error executing MySQL query:', error);
            res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], error: error.message });
        }
    });
    return router;
};

module.exports = initController;

