const express = require('express');

const router = express.Router();

const connection = require('./db');

const languageMessages = require('./language_messages');

const {encodeUserId} = require('./common_function');



// Function to format date

function formatDate(dateString) {
  const date = new Date(dateString);
  const options = { day: '2-digit', month: '2-digit', year: 'numeric', hour: '2-digit', minute: '2-digit', hour12: false};
  const formattedDate = date.toLocaleString('en-US', options);
  return formattedDate;
}

const initController = () => {
  router.get('/getGuestUser', async (req, res) => {
    try {
      const userQuery = `
      SELECT 
          u.user_id, u.email, u.mobile, u.username, u.image, u.active_flag, u.createtime, u.avatar_id, a.avatar_image,u.address,u.latitude,u.longitude,u.password_new,u.role,u.account_currency,u.account_fund_balance,u.note_by_admin,u.about
      FROM 
          user_master u
      LEFT JOIN 
          avatar_master a ON u.avatar_id = a.avatar_id
      WHERE 
          u.delete_flag = 0 AND u.user_type = 1 and u.profile_complete = 1 order by u.user_id desc
      `;

      connection.query(userQuery, (error, userResults) => {
        if (error) {
          console.error('Error executing MySQL query:', error);
          return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }

        console.log('User results:', userResults);

        const users = userResults.map((user, index) => {
          const location = user.latitude ? 
              `<a href="http://www.google.com/maps/place/${user.latitude},${user.longitude}" target="_blank">
                  <span style="color:red;">${user.latitude},${user.longitude}</span>
              </a>
              <p>${user.address}</p>` :
              'NA';
      
          return {
              ...user,
              sr_no: index + 1,
              status: user.active_flag === 1 ? '<span class="badge rounded-pill bg-success inv-badge">Active</span>' : '<span class="badge rounded-pill bg-danger inv-badge">Deactive</span>',
              createtime: formatDate(user.createtime),
              username: "[G]" + user.username,
              action_html: `<div class="btn-group">
                  <a class="dropdown-item edit-btn" href="view_user.html?id=${encodeUserId(user.user_id)}"><i class="fa fa-eye"></i></a>
                  <a class="dropdown-item edit-btn" onclick="btnEditUserConfirm(this)" data-id="${user.user_id}" data-username="${user.username}" data-password_new="${user.password_new}" data-email="${user.email}" data-mobile="${user.mobile}" data-image="${user.image}" data-bio="${user.about}" data-address="${user.address}" data-latitude="${user.latitude}" data-longitude="${user.longitude}" data-note_by_admin="${user.note_by_admin}">
                      <i class="fa fa-edit"></i>
                  </a>
                  <a class="dropdown-item edit-btn" href="javascript:void(0)"  data-id="${user.user_id}" onclick="btnUserDeleteConfirm(this)"><i class="fas fa-trash"></i></a>
              </div>`,
              image_html: `<img  width="50px" src="../server/webservice/images/${user.image}" class="rounded-circle circle-border m-b-md img-fix img-responsive" name="profile_image" id="previewholder" style="width: 70px; height: 70px;" onerror="this.src='assets/images/placeholder.png';">`,
              location: location,
          };
      });
      

        const record = { success: true, msg: languageMessages.msgDataFound[0], data: { users } };
        res.json(record);
      });
    } catch (error) {
      console.error('Error executing MySQL query:', error);
      res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
    }
  });
  return router;
};

module.exports = initController;


