const express = require('express');

const router = express.Router();

const connection = require('./db');

const languageMessages = require('./language_messages');

const { encodeUserId } = require('./common_function');

const { getUserDetails } = require('./common_function_app');



// Function to format date

function formatDate(dateString) {
  const date = new Date(dateString);
  const options = { day: '2-digit', month: '2-digit', year: 'numeric', hour: '2-digit', minute: '2-digit', hour12: true };
  const formattedDate = date.toLocaleString('en-US', options);
  return formattedDate;
}




const initController = () => {

  router.get('/getKeyword', async (req, res) => {

    try {

      const userQuery = 'SELECT keyword_id,user_id,keyword,createtime FROM keyword_master WHERE delete_flag = 0 order by keyword_id desc';

      connection.query(userQuery, async (error, userResults) => {

        if (error) {

          console.error('Error executing MySQL query:', error);

          return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });

        }

        

        try {

          const userDetailsPromises = userResults.map(async (user) => {

            const userDetails = await getUserDetails(user.user_id);

            return userDetails ? userDetails : null;

        });

        

        const userDetailsArray = await Promise.all(userDetailsPromises); // Fixed variable name

        

        const keyword_arr = userResults.map((user, index) => {

          const userDetails = userDetailsArray[index]; // Use userDetailsArray here

          let actionButtons = ''; // Initialize action buttons variable

      

          // Check if userDetails exist and user_type is 0

          if (userDetails && userDetails.user_type === 0) {

              // If user_type is 0, include both edit and delete buttons

              actionButtons = `<li><a class="dropdown-item" href="edit_keyword.html?id=${encodeUserId(user.keyword_id)}"><i class="fa fa-edit"></i> Edit</a></li>

                               <li><a class="dropdown-item" onclick="deleteKeyword(${(user.keyword_id)})"><i class="fa fa-trash"></i>Delete</a></li>`;

          } else {

              // If user_type is not 0, do not include any buttons

              actionButtons = '';

          }

      

          return {

              ...user,

              sr_no: index + 1,

              createtime: formatDate(user.createtime),

              action_html: `<div class="btn-group">

                  <button type="button" class="btn btn-primary dropdown-toggle float-button-light" id="primary-dropdown-outline" data-toggle="dropdown" aria-expanded="false">

                      Action

                  </button>

                  <ul class="dropdown-menu dropdown-menu-primary" style="margin: 2px -56px 0;" aria-labelledby="primary-dropdown" role="menu">

                      ${actionButtons} <!-- Include action buttons here -->

                  </ul>

              </div>`,

              username: userDetails ? userDetails.username : null // Adding username to the user object

          };

      });

      

        const record = { success: true, msg: languageMessages.msgDataFound[0], data: { keyword_arr } };

        res.json(record);

        } catch (error) {

          console.error('Error fetching user details:', error);

          res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });

        }

      });

    } catch (error) {

      console.error('Error executing MySQL query:', error);

      res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });

    }

  });



  return router;

};



module.exports = initController;

