const express = require('express');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const { encodeUserId } = require('./common_function');
const { getUserDetails } = require('./common_function_app');

// Function to format date
function formatDate(dateString) {
    const date = new Date(dateString);
    const options = { day: '2-digit', month: '2-digit', year: 'numeric', hour: '2-digit', minute: '2-digit', hour12: false };
    const formattedDate = date.toLocaleString('en-US', options);
    return formattedDate;
}

const initController = () => {
    router.get('/getLocalPost', async (req, res) => {
        try {
            const type = req.query.type;
            connection.query('SELECT post_show_km FROM admin_manage_master', (err, rows) => {
                if (err) {
                  console.error('Error fetching top_post_show_km:', err);
                  return;
                }
              
                // Assuming top_post_show_km is a single value, if not, you might need to extract it from rows
                const topLocalShowKm = rows[0].post_show_km;
            let userQuery = `
                SELECT 
                    p.post_id, p.user_id, p.caption, p.location, p.latitude, p.longitude, p.createtime, p.created_by
                FROM 
                    post_master p`;

            if (type == 0) {
                userQuery += `
                    WHERE 
                        p.delete_flag = 0 AND p.post_type = 0
                    ORDER BY 
                        p.post_id DESC`;
            } else {
                userQuery += `
                    LEFT JOIN 
                        admin_manage_master a ON 1=1
                    WHERE 
                        p.delete_flag = 0 AND p.post_type = 0 AND a.latitude IS NOT NULL AND a.longitude IS NOT NULL
                    ORDER BY 
                        SQRT(POW(p.latitude - a.latitude, 2) + POW(p.longitude - a.longitude, 2)) ASC LIMIT ?`;
            }

            connection.query(userQuery,[topLocalShowKm], async (error, userResults) => {
                if (error) {
                    console.error('Error executing MySQL query:', error);
                    return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0],'type':type,'error':error });
                }

                try {
                    const userDetailsPromises = userResults.map(async (user) => {
                        const userDetails = await getUserDetails(user.user_id);
                        return userDetails ? userDetails.username : null; // Assuming username is stored in 'name' field
                    });

                    const userDetails = await Promise.all(userDetailsPromises);

                    const post_arr = userResults.map((user, index) => ({
                        ...user,
                        sr_no: index + 1,
                        createtime: formatDate(user.createtime),
                        action_html: `<div class="btn-group">
                            <a class="dropdown-item edit-btn" onclick="viewAdminPost(${user.post_id})"><i class="fa fa-eye"></i></a>
                            <a href="#" class="dropdown-item edit-btn" data-id="${user.post_id}" onclick="btnEditPostConfirm(this)"><i class="fa fa-edit"></i></a> 
                            <a class="dropdown-item edit-btn" onclick="deleteAdminPost(${user.post_id})"><i class="fa fa-trash"></i></a>
                        </div>`,
                        location: `<a href="http://www.google.com/maps/place/${user.latitude},${user.longitude}" target="_blank"><span style="color:red;">${user.latitude},${user.longitude}</span></a>
                            <p>${user.location}</p>`,
                        username: userDetails[index], // Adding username to the user object
                        caption : user.caption ? user.caption:'NA'
                    }));

                    const record = { success: true, msg: languageMessages.msgDataFound[0], data: { post_arr },'type':type,'error':error };
                    res.json(record);
                } catch (error) {
                    console.error('Error fetching user details:', error);
                    res.status(500).json({ success: false, msg: languageMessages.internalServerError[0],'type':type,'error':error });
                }
            });
        });
        } catch (error) {
            console.error('Error executing MySQL query:', error);
            res.status(500).json({ success: false, msg: languageMessages.internalServerError[0],'type':type,'error':error });
        }
    });
    return router;
};

module.exports = initController;
