// mailfunction.js

const nodemailer = require('nodemailer');

const { mail_host, mail_username, mail_password, mail_SMTPSecure, mail_port, mail_from } = require('./mail_config');



// Nodemailer transporter

const transporter = nodemailer.createTransport({

    host: mail_host,

    port: mail_port,

    secure: mail_SMTPSecure === 'ssl', // true for 465, false for other ports

    auth: {

        user: mail_username,

        pass: mail_password,

    },

    tls: {

        rejectUnauthorized: false, // for testing purposes only, to avoid certificate validation errors

    },

});



// Function to send email

async function sendMail(email, fromName, subject,mailBody) {

    const mailOptions = {

        from: mail_from,

        to: email,

        subject: subject,

        html: mailBody,

    };



    try {

        const info = await transporter.sendMail(mailOptions);

        console.log('Email sent:', info.response);

        return { success: true, message: 'Email sent successfully', info };

    } catch (error) {

        console.error('Error sending email:', error);

        return { success: false, message: 'Failed to send email', error: error.message };

    }

}



// Function to generate email body

function ActiveDeactiveSendMail(postData) {

    const year = new Date().getFullYear();



    const mailBody = `

        <!DOCTYPE html>

        <html>

            <head>

                <meta name="viewport" content="width=device-width, initial-scale=1" />

                <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

                <title>Welcome to ${postData.fromName}</title>

            </head>

            <body style="margin: 0; padding: 0; background-color:#f94001; font-size:13px; color:#444; font-family:Arial, Helvetica, sans-serif; padding-top:70px; padding-bottom:70px;">

                <table cellspacing="0" cellpadding="0" align="center" width="768" class="outer-tbl" style="margin:0 auto;">

                    <tr>

                        <td class="pad-l-r-b" style="background-color:#FFFFFF; padding:0 70px 40px;">

                            <table cellpadding="0" cellspacing="0" class="full-wid">

            

                            </table>

            

                            <table cellpadding="0" cellspacing="0" style="width:100%; background-color:#FFFFFF; border-radius:4px;box-shadow:0 0 20px #ccc;margin-top:40px">

                                <tr>

                                    <td>

                                        <table border="0" style="margin:0; width:100%" cellpadding="0" cellspacing="0">

                                            <tr style="background:#f94001;">

                                                <td class="logo" style="padding:40px 0 30px 0; text-align:center; border-bottom:1px solid #000000;background-color: #f94001;">

                                                    <img src="${postData.app_logo}" alt="" width="15%" height="18%" style="background-color: #e4d7d2; padding:5px">

                                                    <h1 style="color:white;">Manage Account</h1>

                                                </td>

                                            </tr>

                                            <tr><td></td></tr>

                                            <tr>

                                                <td class="content" style="padding:40px 40px;">

                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#060b48; margin-top:0">

                                                    </p>

                                

                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#060b48; margin-top:0">${postData.mailContent}</p>

                                

                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#060b48; margin-top:0">

                                                    Regards,                  

                                                    </p>

                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#060b48; margin-top:0">

                                                    ${postData.fromName}                    

                                                    </p>

                                                </td>

                                            </tr>

                                            <tr>

                                                <td style="background:#f94001; padding-bottom:60px;">

                                                    <table style="width:100%;background-color: #f94001;" border="0" cellspacing="0" cellpadding="0" class="full-wid" align="center">

                                                        <tr>

                                                            <td>   

                                                                <div style="margin:0 auto; text-align:center; padding:0 100px" class="foot-items">

                                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:14px; color:#fffcfc; margin-top:40px; line-height:20px;">

                                                                    &#169; ${year} ${postData.fromName} | All right Reserved

                                                                    </p>

                                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:12px; color:#fffcfc; line-height:20px; margin-bottom:40px;">

                                                                    The content of this message is confidential. If you have received it by mistake, please inform us by an email reply and then delete the message. It is forbidden to copy, forward, or in any way reveal the contents of this message to anyone.

                                                                    </p>

                                                                </div>

                                                            </td>

                                                        </tr>

                                                    </table>

                                                </td>

                                            </tr>

                                        </table>

                                    </td>

                                </tr>

                            </table>

                        </td>

                    </tr>

                </table>

            </body>

        </html>

    `;



    return mailBody;

}


function AddVIPAccount(postData) {

    const year = new Date().getFullYear();



    const mailBody = `

        <!DOCTYPE html>

        <html>

            <head>

                <meta name="viewport" content="width=device-width, initial-scale=1" />

                <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

                <title>Welcome to ${postData.fromName}</title>

            </head>

            <body style="margin: 0; padding: 0;font-size:13px; color:#444; font-family:Arial, Helvetica, sans-serif; padding-top:70px; padding-bottom:70px;">

                <table cellspacing="0" cellpadding="0" align="center" width="768" class="outer-tbl" style="margin:0 auto;">

                    <tr>

                        <td class="pad-l-r-b" style="background-color:#FFFFFF; padding:0 70px 40px;">

                            <table cellpadding="0" cellspacing="0" class="full-wid">

            

                            </table>

            

                            <table cellpadding="0" cellspacing="0" style="width:100%; background-color:#FFFFFF; border-radius:4px;box-shadow:0 0 20px #ccc;margin-top:40px">

                                <tr>

                                    <td>

                                        <table border="0" style="margin:0; width:100%" cellpadding="0" cellspacing="0">

                                            <tr style="background:#f94001;">

                                                <td class="logo" style="padding:40px 0 30px 0; text-align:center; border-bottom:1px solid #000000;background-color: #f94001;">

                                                    <img src="${postData.app_logo}" alt="" width="15%" height="18%" style="background-color: #e4d7d2; padding:5px">

                                                    <h1 style="color:white;">Account Credentials</h1>

                                                </td>

                                            </tr>

                                            <tr><td></td></tr>

                                            <tr>

                                                <td class="content" style="padding:40px 40px;">

                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#060b48; margin-top:0">

                                                    </p>

                                

                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#060b48; margin-top:0">${postData.mailContent}</p>

                                

                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#060b48; margin-top:0">

                                                    Regards,                  

                                                    </p>

                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#060b48; margin-top:0">

                                                    ${postData.fromName}                    

                                                    </p>

                                                </td>

                                            </tr>

                                            <tr>

                                                <td style="background:#f94001; padding-bottom:60px;">

                                                    <table style="width:100%;background-color: #f94001;" border="0" cellspacing="0" cellpadding="0" class="full-wid" align="center">

                                                        <tr>

                                                            <td>   

                                                                <div style="margin:0 auto; text-align:center; padding:0 100px" class="foot-items">

                                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:14px; color:#fffcfc; margin-top:40px; line-height:20px;">

                                                                    &#169; ${year} ${postData.fromName} | All right Reserved

                                                                    </p>

                                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:12px; color:#fffcfc; line-height:20px; margin-bottom:40px;">

                                                                    The content of this message is confidential. If you have received it by mistake, please inform us by an email reply and then delete the message. It is forbidden to copy, forward, or in any way reveal the contents of this message to anyone.

                                                                    </p>

                                                                </div>

                                                            </td>

                                                        </tr>

                                                    </table>

                                                </td>

                                            </tr>

                                        </table>

                                    </td>

                                </tr>

                            </table>

                        </td>

                    </tr>

                </table>

            </body>

        </html>

    `;



    return mailBody;

}



function mailBodyForgotPasswordData(postData) {
    const date = new Date().getFullYear();
    const mailBody = `
        <!DOCTYPE html>
        <html>
        <head>
            <meta name="viewport" content="width=device-width, initial-scale=1">
            <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
            <title>Welcome to ${postData.fromName}</title>
        </head>
        <body style="margin: 0; padding: 0; background-color:#000000; font-size:13px; color:#444; font-family:Arial, Helvetica, sans-serif; padding-top:70px; padding-bottom:70px;">
            <table cellspacing="0" cellpadding="0" align="center" width="768" class="outer-tbl" style="margin:0 auto;">
                <tr>
                    <td class="pad-l-r-b" style="background-color:#FFFFFF; padding:0 70px 40px;">
                        <table cellpadding="0" cellspacing="0" class="full-wid">
            
                        </table>
                        <table cellpadding="0" cellspacing="0" style="width:100%; background-color:#FFFFFF; border-radius:4px;box-shadow:0 0 20px #ccc;margin-top:40px">
                            <tr>
                                <td>
                                    <table border="0" style="margin:0; width:100%" cellpadding="0" cellspacing="0">
                                        <tr>
                                            <td class="logo" style="padding:40px 0 30px 0; background-color:#f94001; text-align:center; border-bottom:1px solid #E1E1E1">
                                                <img src="${postData.app_logo}" alt="" width="15%" height="18%" style="background-color: white; padding:5px">
                                                <h1 style="color:white;">Forgot Your Password</h1>
                                            </td>
                                        </tr>
                                        <tr><td></td></tr>
                                        <tr>
                                            <td class="content" style="padding:40px 40px;">
                                                <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#333333; margin-top:0">
                                                    Hello ${postData.name}
                                                </p>
                                                <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#333333; margin-top:0">
                                                ${ postData.mailContent}
                                                </p>
                                                <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#333333; margin-top:0">
                                                    Regards,
                                                </p>
                                                <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#333333; margin-top:0">
                                                ${ postData.fromName }
                                                </p>
                                            </td>
                                        </tr>
                                        <tr>
                                            <td style="background:#f94001; padding-bottom:60px;">
                                                <table style="width:100%" border="0" cellspacing="0" cellpadding="0" class="full-wid" align="center">
                                                    <tr>
                                                        <td>
                                                            <div style="margin:0 auto; text-align:center; padding:0 100px" class="foot-items">
                                                                <p style="font-family:Arial, Helvetica, sans-serif; font-size:14px; color:#fbfbfb; margin-top:40px; line-height:20px;">
                                                                    &#169; ${ date } ${ postData.fromName } | All right Reserved
                                                                </p>
                                                                <p style="font-family:Arial, Helvetica, sans-serif; font-size:12px; color:#fbfbfb; line-height:20px; margin-bottom:40px;">
                                                                    The content of this message is confidential. If you have received it by mistake, please inform us by an email reply and then delete the message. It is forbidden to copy, forward, or in any way reveal the contents of this message to anyone.
                                                                </p>
                                                            </div>
                                                        </td>
                                                    </tr>
                                                </table>
                                            </td>
                                        </tr>
                                    </table>
                                </td>
                            </tr>
                        </table>
                    </td>
                </tr>
            </table>
        </body>
        </html>
    `;

    return mailBody;
}

function UserContacUs(postData) {

    const year = new Date().getFullYear();



    const mailBody = `

        <!DOCTYPE html>

        <html>

            <head>

                <meta name="viewport" content="width=device-width, initial-scale=1" />

                <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

                <title>Welcome to ${postData.fromName}</title>

            </head>

            <body style="margin: 0; padding: 0;font-size:13px; color:#444; font-family:Arial, Helvetica, sans-serif; padding-top:70px; padding-bottom:70px;">

                <table cellspacing="0" cellpadding="0" align="center" width="768" class="outer-tbl" style="margin:0 auto;">

                    <tr>

                        <td class="pad-l-r-b" style="background-color:#FFFFFF; padding:0 70px 40px;">

                            <table cellpadding="0" cellspacing="0" class="full-wid">

            

                            </table>

            

                            <table cellpadding="0" cellspacing="0" style="width:100%; background-color:#FFFFFF; border-radius:4px;box-shadow:0 0 20px #ccc;margin-top:40px">

                                <tr>

                                    <td>

                                        <table border="0" style="margin:0; width:100%" cellpadding="0" cellspacing="0">

                                            <tr style="background:#f94001;">

                                                <td class="logo" style="padding:40px 0 30px 0; text-align:center; border-bottom:1px solid #000000;background-color: #f94001;">

                                                    <img src="${postData.app_logo}" alt="" width="15%" height="18%" style="background-color: #e4d7d2; padding:5px">

                                                    <h1 style="color:white;">Contact Us</h1>

                                                </td>

                                            </tr>

                                            <tr><td></td></tr>

                                            <tr>

                                                <td class="content" style="padding:40px 40px;">

                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#060b48; margin-top:0">

                                                    </p>

                                

                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#060b48; margin-top:0">${postData.mailContent}</p>

                                

                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#060b48; margin-top:0">

                                                    Regards,                  

                                                    </p>

                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:15px; color:#060b48; margin-top:0">

                                                    ${postData.fromName}                    

                                                    </p>

                                                </td>

                                            </tr>

                                            <tr>

                                                <td style="background:#f94001; padding-bottom:60px;">

                                                    <table style="width:100%;background-color: #f94001;" border="0" cellspacing="0" cellpadding="0" class="full-wid" align="center">

                                                        <tr>

                                                            <td>   

                                                                <div style="margin:0 auto; text-align:center; padding:0 100px" class="foot-items">

                                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:14px; color:#fffcfc; margin-top:40px; line-height:20px;">

                                                                    &#169; ${year} ${postData.fromName} | All right Reserved

                                                                    </p>

                                                                    <p style="font-family:Arial, Helvetica, sans-serif; font-size:12px; color:#fffcfc; line-height:20px; margin-bottom:40px;">

                                                                    The content of this message is confidential. If you have received it by mistake, please inform us by an email reply and then delete the message. It is forbidden to copy, forward, or in any way reveal the contents of this message to anyone.

                                                                    </p>

                                                                </div>

                                                            </td>

                                                        </tr>

                                                    </table>

                                                </td>

                                            </tr>

                                        </table>

                                    </td>

                                </tr>

                            </table>

                        </td>

                    </tr>

                </table>

            </body>

        </html>

    `;



    return mailBody;

}


module.exports = { sendMail, ActiveDeactiveSendMail,AddVIPAccount,mailBodyForgotPasswordData,UserContacUs };

