const express = require('express');
const crypto = require('crypto');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages'); // Import language messages

// Middleware for parsing request bodies
router.use(express.json());
router.use(express.urlencoded({ extended: true }));

const initController = () => {
    router.post('/reset_password', async (req, res) => {
        const { uniqcode, password } = req.body;
        try {
            // Check for missing fields
            if (!uniqcode || !password) {
                return res.json({ success: false, msg: languageMessages.allFieldsRequired, data: {} });
            }

            const hashedPassword = md5(password);
            
            // Query to fetch the forgot password details
            connection.query('SELECT forgot_id, user_id FROM forgot_password_master WHERE active_flag = 0 AND forgot_pass_identity = ?', [uniqcode], (error, results, fields) => {
                if (error) {
                    console.error('Error fetching forgot password details:', error);
                    return res.status(500).json({ success: false, msg: languageMessages.errorResetPassword[0] });
                }
                
                if (!results || results.length === 0) {
                    return res.json({ success: false, msg: languageMessages.errorResetPassword[0], data: {} });
                }

                const userId = results[0].user_id;

                // Update user's password and update forgot password record
                connection.query('UPDATE user_master SET password = ?,password_new=?, updatetime = ? WHERE user_id = ?', [hashedPassword,password, new Date(), userId], (updateError, updateResults) => {
                    if (updateError) {
                        console.error('Error updating user password:', updateError);
                        return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
                    }

                    if (updateResults.affectedRows === 0) {
                        return res.json({ success: false, msg: languageMessages.errorResetPassword[0], data: {} });
                    }

                    // Update forgot password record
                    connection.query('UPDATE forgot_password_master SET active_flag = 1, updatetime = ? WHERE forgot_pass_identity = ?', [new Date(), uniqcode], (updateForgotError) => {
                        if (updateForgotError) {
                            console.error('Error updating forgot password record:', updateForgotError);
                            return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
                        }
                        
                        return res.json({ success: true, msg: languageMessages.ResetPasswordSuccessfully[0] });
                    });
                });
            });

        } catch (error) {
            console.error('Unexpected error:', error);
            return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], data: {} });
        }
    });
    
    return router;
};

// MD5 hashing function (Not recommended for passwords)
function md5(input) {
    return crypto.createHash('md5').update(input).digest('hex');
}

module.exports = initController;
