const express = require('express');
const multer = require('multer');
const crypto = require('crypto');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages');
const { sendMail, AddVIPAccount } = require('./mailfunction.js');
const { app_name, app_logo,currentTime } = require('./site_config');

//console.log('login');

router.use(express.json());
router.use(express.urlencoded({ extended: true }));
const upload = multer();
router.use(upload.none());

const initController = () => {
    router.post('/send_reply', async (req, res) => {
        try {
            const { contact_id, user_email, user_name, message, title } = req.body;
            // Check if required fields are provided
            if (!contact_id || !user_email || !message || !user_name || !title) {
                return res.status(400).json({ success: false, msg: languageMessages.allFieldsRequired[0], 'error': req.body });
            }

            // Send email notification
            const fromName = app_name;
            const subject = 'Contact Us Reply';
            const mailContent = `
                <p>Hello ${user_name},</p>
                <p>Message: ${message}</p>
            `;
            const mailBody = AddVIPAccount({ user_email, fromName, subject, mailContent, app_logo, name: user_name });
            sendMail(user_email, fromName, subject, mailBody)
                .then(response => {
                    console.log('Email response:', response);
                    // Update contact_us_master after mail send
                    const updateQuery = `UPDATE contact_us_master SET status = 1,reply_datetime=? WHERE contact_id = ?
                    `;
                    connection.query(updateQuery, [currentTime,contact_id], (updateError, updateResult) => {
                        if (updateError) {
                            console.error('Error updating contact_us_master:', updateError);
                            return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], 'error': updateError });
                        }
                        console.log('Contact us master updated successfully');
                        return res.status(200).json({ success: true, msg: languageMessages.msgGuestSendMailSuccess[0] });
                    });
                })
                .catch(error => {
                    console.error('Error sending email:', error);
                    return res.status(500).json({ success: false, msg: languageMessages.msgGuestSendMailError[0], 'error': error });
                });
        } catch (error) {
            console.error('Error handling request:', error);
            return res.status(500).json({ success: false, msg: languageMessages.msgGuestSendMailError[0], 'error': error });
        }
    });

    return router;
};

module.exports = initController;
