const express = require('express');

const multer = require('multer');

const crypto = require('crypto');

const router = express.Router();

const connection = require('./db');

const languageMessages = require('./language_messages'); // Import language messages



// Middleware for parsing request bodies

router.use(express.json());

router.use(express.urlencoded({ extended: true }));

const upload = multer();

router.use(upload.none());



const initController = () => {

    router.post('/signin', async (req, res) => {

        const { email, password } = req.body;



        try {

            if (!email || !password) {

                return res.json({ success: false, msg: languageMessages.allFieldsRequired, data: {} });

            }



            const hashedPassword = md5(password);



            connection.query('SELECT user_id, user_type FROM user_master WHERE delete_flag = 0 AND (email = ? or username=?) AND password=? AND user_type IN (0,2) and role=0', [email,email, hashedPassword], async (error, results, fields) => {

                if (error) {

                    console.error(error);

                    return res.status(200).json({ success: false, msg: languageMessages.internalServerError[0], data: {} });

                }



                if (!results || results.length === 0) {

                    return res.json({ success: false, msg: languageMessages.invalidCredentials[0], data: {} });

                }



                const { user_id, user_type } = results[0];

               

                // Set session data

                return res.json({ success: true, msg: languageMessages.loginSuccessful[0], data: { email, user_id, user_type } });

            });

        } catch (error) {

            console.error(error);

            return res.status(200).json({ success: false, msg: languageMessages.internalServerError[0], data: {} });

        }

    });



    return router;

};



// MD5 hashing function (Not recommended for passwords)

function md5(input) {

    return crypto.createHash('md5').update(input).digest('hex');

}



module.exports = initController;

