const express = require('express');

const router = express.Router();

const connection = require('./db');

const languageMessages = require('./language_messages');

const { encodeUserId } = require('./common_function');

const { getUserDetails } = require('./common_function_app');



// Function to format date

function formatDate(dateString) {
  const date = new Date(dateString);
  const options = { day: '2-digit', month: '2-digit', year: 'numeric', hour: '2-digit', minute: '2-digit', hour12: false};
  const formattedDate = date.toLocaleString('en-US', options);
  return formattedDate;
}



const initController = () => {
  router.get('/getSubAdminLocalPost', async (req, res) => {
    try {
        const user_id = req.query.userId;
    //   let userQuery = `
    //     SELECT 
    //       p.post_id, p.user_id, p.caption, p.location, p.latitude, p.longitude, p.createtime, p.created_by,
    //       a.latitude AS admin_latitude, a.longitude AS admin_longitude
    //     FROM 
    //       post_master p`;

    //   const adminLocationQuery = `
    //     LEFT JOIN 
    //       admin_manage_master a ON 1=1`;

    //   // Define the condition to check if admin_manage_master latitude and longitude are not empty
    //   const adminLocationCondition = 'a.latitude IS NOT NULL AND a.longitude IS NOT NULL';

    //   // Append the adminLocationQuery only if admin_manage_master has non-empty latitude and longitude
    //   userQuery += (adminLocationCondition ? adminLocationQuery : '');

    //   userQuery += `
    //     WHERE 
    //       p.delete_flag = 0 AND p.post_type = 1 and p.user_id=?
    //     ORDER BY 
    //       IF(a.latitude IS NULL OR a.longitude IS NULL, 1, SQRT(POW(p.latitude - a.latitude, 2) + POW(p.longitude - a.longitude, 2))) ASC limit 499`;

    let userQuery = `
        SELECT 
            p.post_id, p.user_id, p.caption, p.location, p.latitude, p.longitude, p.createtime, p.created_by
        FROM 
            post_master p`;

        userQuery += `
        WHERE 
            p.delete_flag = 0 AND p.post_type = 0 AND p.user_id=?
        ORDER BY 
            p.post_id DESC`;

      connection.query(userQuery,[user_id], async (error, userResults) => {
        if (error) {
          console.error('Error executing MySQL query:', error);
          return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }
        
        try {
          const userDetailsPromises = userResults.map(async (user) => {
            const userDetails = await getUserDetails(user.user_id);
            return userDetails ? userDetails.username : null; // Assuming username is stored in 'name' field
          });

          const userDetails = await Promise.all(userDetailsPromises);

          const post_arr = userResults.map((user, index) => ({
            ...user,
            sr_no: index + 1,
            createtime: formatDate(user.createtime),
            action_html: `<div class="btn-group">
            <a class="dropdown-item edit-btn" onclick="viewAdminPost(${(user.post_id)})" ><i class="fa fa-eye"></i></a>
            <a class="dropdown-item edit-btn" data-id="${user.post_id}" onclick="btnEditPostConfirm(this)"><i class="fa fa-edit"></i></a>
            <a class="dropdown-item edit-btn" onclick="deleteAdminPost(${(user.post_id)})"><i class="fa fa-trash"></i></a>
            </div>`,
            location : `<a href="http://www.google.com/maps/place/${user.latitude},${user.longitude}" target="_blank"><span style="color:red;">${user.latitude},${user.longitude}</span></a>
            <p>${user.location}</p>`,
            username: userDetails[index], // Adding username to the user object
            caption : user.caption ? user.caption:'NA'
          }));

          const record = { success: true, msg: languageMessages.msgDataFound[0], data: { post_arr } };
          res.json(record);
        } catch (error) {
          console.error('Error fetching user details:', error);
          res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }
      });
    } catch (error) {
      console.error('Error executing MySQL query:', error);
      res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
    }
  });
  return router;
};


module.exports = initController;

