const express = require('express');
const multer = require('multer');
const crypto = require('crypto');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages'); // Import language messages

// Middleware for parsing request bodies
router.use(express.json());
router.use(express.urlencoded({ extended: true }));
const upload = multer();
router.use(upload.none());

const initController = () => {
    router.post('/subadminsignin', async (req, res) => {
        const { username, password } = req.body;

        try {
            if (!username || !password) {
                return res.json({ success: false, msg: languageMessages.allFieldsRequired, data: {} });
            }

            const hashedPassword = md5(password);

            connection.query(
                'SELECT user_id, user_type FROM user_master WHERE delete_flag = 0 AND username = ? AND password=? AND user_type IN (2) and role=1',
                [username, hashedPassword],
                async (error, results, fields) => {
                    if (error) {
                        console.error(error);
                        return res.json({ success: false, msg: languageMessages.internalServerError[0], error: error });
                    }

                    if (!results || results.length === 0) {
                        return res.json({ success: false, msg: languageMessages.invalidUsernameCredentials[0], data: { error: results.length } });
                    }

                    const { user_id, user_type } = results[0];

                    // Set session data
                   
                    return res.json({ success: true, msg: languageMessages.loginSuccessful[0], data: { username, user_id, user_type } });
                }
            );
        } catch (error) {
            console.error(error);
            return res.status(200).json({ success: false, msg: languageMessages.internalServerError[0], error: error });
        }
    });

    return router;
};

// MD5 hashing function (Not recommended for passwords)
function md5(input) {
    return crypto.createHash('md5').update(input).digest('hex');
}

module.exports = initController;
