// Import necessary modules
//keywordEditController.js
const express = require('express');
const multer = require('multer');
const crypto = require('crypto');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages'); // Import language messages

// Middleware setup for parsing requests
router.use(express.json());
router.use(express.urlencoded({ extended: true }));

// Multer setup for handling multipart/form-data
const upload = multer();
router.use(upload.none());

// Route to handle editing keywords
const initController = () => {
  router.post('/update_admin_manage_count', async (req, res) => {
    try {
      // Validate inputs
      const manage_id = req.body.manage_id;
      const post_like_count = req.body.post_like_count;
      const post_dislike_count = req.body.post_dislike_count;
      const local_post_count = req.body.local_post_count;
      const post_show_km = req.body.post_show_km;
      // const post_show_miles = req.body.post_show_miles;
      // const home_top_count  = req.body.home_top_count ;
      // const home_local_count  = req.body.home_local_count ;
      const post_disappear_delete_day = req.body.post_disappear_delete_day;

      const top_post_show_km = req.body.top_post_show_km;
      // const top_post_show_miles = req.body.top_post_show_miles;
      const top_post_disappear_delete_day = req.body.top_post_disappear_delete_day;
      const min_word = req.body.min_word;
      const max_word = req.body.max_word;
      const guest_account_delete = req.body.guest_account_delete;
      const top_post_fee_yuan = req.body.top_post_fee_yuan;
      const top_post_fee_usd = req.body.top_post_fee_usd;
      const completely_delete_post = req.body.completely_delete_post;

      // Check if any required field is missing
      if (!manage_id || !post_like_count || !post_dislike_count || !local_post_count || !post_show_km || !post_disappear_delete_day || !top_post_show_km  || !top_post_disappear_delete_day || !min_word || !max_word || !guest_account_delete || !top_post_fee_yuan || !top_post_fee_usd) {
        return res.status(400).json({ success: false, msg: languageMessages.allFieldsRequired[0] });
      }

      // Update keyword in the database
      const query = 'UPDATE admin_manage_master SET post_like_count = ?, post_dislike_count = ?, local_post_count = ?, post_show_km = ?,post_disappear_delete_day=?,top_post_show_km=?,top_post_disappear_delete_day=?,min_word=?,max_word=?,guest_account_delete=?,top_post_fee_yuan=?,top_post_fee_usd=?, updatetime = NOW(),completely_delete_post=? WHERE manage_id = ?';
      connection.query(query, [post_like_count, post_dislike_count, local_post_count, post_show_km,post_disappear_delete_day,top_post_show_km,top_post_disappear_delete_day,min_word,max_word,guest_account_delete,top_post_fee_yuan,top_post_fee_usd,completely_delete_post, manage_id], (error, results) => {
        if (error) {
          console.error('Error updating count:', error);
          return res.status(500).json({ success: false, msg: languageMessages.errorDeleteCountUpdate[0] });
        }
        return res.status(200).json({ success: true, msg: languageMessages.countUpdateSuccessfully[0] });
      });
    } catch (error) {
      console.error('Error updating count:', error);
      return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0],error:error });
    }
  });

  return router;
};

module.exports = initController;
