const express = require('express');
const multer = require('multer');
const crypto = require('crypto');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages'); // Import language messages
const {currentTime } = require('./site_config');

//const upload = multer({ storage: storage });
router.use(express.json());
router.use(express.urlencoded({ extended: true }));
const upload = multer();
router.use(upload.none());

const initController = () => {
    router.post('/edit_password', async (req, res) => {
        try {
            const id = req.body.id;
            const old_password = req.body.old_password;
            const new_password = req.body.new_password;

            // Check if required fields are provided
            if (!id || !old_password || !new_password) {
              return res.status(400).json({ success: false, msg: languageMessages.allFieldsRequired[0],error:req.body });
            }
            // Merge default values with the request body
          
            const hashedPassword = md5(new_password);

            // Check if username already exists
            const checkUsernameQuery = 'SELECT user_id FROM user_master WHERE password_new = ? and user_id=?';
            connection.query(checkUsernameQuery, [new_password, id], (newPasswordError, newPasswordResults) => {
                if (newPasswordError) {
                    console.error('Error checking new_password:', newPasswordError);
                    return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], error: newPasswordError });
                }
                if (newPasswordResults.length > 0) {
                  return res.status(200).json({ success: false, msg: languageMessages.msgNewPasswordError[0] });
                }

                
                    // Check if email already exists
                    const checkEmailQuery = 'SELECT user_id FROM user_master WHERE password_new!=? AND user_id=?';
                    connection.query(checkEmailQuery, [old_password, id], (oldPasswordError, oldPasswordResults) => {
                        if (oldPasswordError) {
                            console.error('Error checking email:', oldPasswordError);
                            return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], error: oldPasswordError });
                        }
                        if (oldPasswordResults.length > 0) {
                            return res.status(200).json({ success: false, msg: languageMessages.msgOldPasswordError[0] });
                        }

                        // Update user details in the database
                        let updateQuery = `UPDATE user_master SET  password = ?, password_new = ?, updatetime = ? WHERE user_id = ?` ;
                        let queryValues = [ hashedPassword, new_password,currentTime,id];
                        // Execute the database update query
                        connection.query(updateQuery, queryValues, (updateError, updateResults) => {
                            if (updateError) {
                                console.error('Error updating user:', updateError);
                                return res.status(500).json({ success: false, msg: languageMessages.msgPasswordUpdateError[0], error: updateError });
                            }
                            return res.status(200).json({ success: true, msg: languageMessages.msgPasswordUpdateSuccess[0] });
                        });
                    });
                
            });
        } catch (error) {
            console.error('Error handling request:', error);
            return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0], error: error });
        }
    });

    return router;
};

// MD5 hashing function
function md5(input) {
    return crypto.createHash('md5').update(input).digest('hex');
}

module.exports = initController;
