// Import necessary modules
const express = require('express');
const multer = require('multer');
const crypto = require('crypto');
const router = express.Router();
const connection = require('./db');
const languageMessages = require('./language_messages'); // Import language messages
const { sendMail, ActiveDeactiveSendMail } = require('./mailfunction.js');
const { app_name, app_logo } = require('./site_config');

//console.log('login');
router.use(express.json());
router.use(express.urlencoded({ extended: true }));
const upload = multer();
router.use(upload.none());

// Route to handle editing keywords
const initController = () => {
  router.post('/active_deactive', async (req, res) => {
    try {
      // Validate keyword and keyword_id
      const user_id = req.body.user_id;
      const status = req.body.status;
   
      // Update keyword in the database
      const query = 'UPDATE user_master SET active_flag = ?, updatetime = NOW() WHERE user_id = ?'; // Assuming 'keyword_master' is your table name
      connection.query(query, [status,user_id], (error, results) => {
        if (error) {
          if(status==1){
            return res.status(500).json({ success: false, msg: languageMessages.msgUserActivatederror[0] });
          }else{
            return res.status(500).json({ success: false, msg: languageMessages.msgUserDeactivatederror[0] });
          }
        }
        // Fetch user details from the database
        const userDetailQuery = 'SELECT name, email FROM user_master WHERE user_id = ?';
        connection.query(userDetailQuery, [user_id], (userError, userResults) => {
        if (userError || !userResults.length) {
            console.error('Error fetching user details:', userError);
            return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
        }

        const { name, email } = userResults[0];
        const fromName = app_name;
        
        const subject = 'Account Info';
        let mailContent;
        if(status==1){
             mailContent = `Hello ${name},<br>Your account has been <b>activated</b> by administration.`;
        }else{
             mailContent = `Hello ${name},<br>Your account has been <b>deactivated</b> by administration.`;
        }
        
        const mailBody = ActiveDeactiveSendMail({email,fromName,subject,mailContent,app_logo,name});

        // Call sendMail function
        sendMail(email, fromName, subject, mailBody)
            .then(response => {
            console.log('Email response:', response);
            })
            .catch(error => {
            console.error('Error sending email:', error);
            });
        });
        if(status==1){
            return res.status(200).json({ success: true, msg: languageMessages.msgUserActivatedSuccess[0] });
        }else{
            return res.status(200).json({ success: true, msg: languageMessages.msgUserDeactivatedSuccess[0] });
        }

        
      });
    } catch (error) {
      console.error('Error handling request:', error);
      return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });
    }
  });
  return router;
};

module.exports = initController;
