const express = require('express');

const router = express.Router();

const connection = require('./db');

const languageMessages = require('./language_messages');

const {encodeUserId} = require('./common_function');
const { spawn } = require('child_process');

// Function to format date

function formatDate(dateString) {
  const date = new Date(dateString);
  const options = { day: '2-digit', month: '2-digit', year: 'numeric', hour: '2-digit', minute: '2-digit', hour12: false};
  const formattedDate = date.toLocaleString('en-US', options);
  return formattedDate;
}



const initController = () => {

  router.get('/getVipUser', async (req, res) => {

    try {

      const userQuery = `
      SELECT 
          u.user_id, u.email, u.mobile, u.username, u.image, u.active_flag, u.createtime, u.avatar_id, a.avatar_image,u.address,u.latitude,u.longitude,u.password_new,u.role,u.account_currency,u.account_fund_balance,u.note_by_admin,u.about,u.current_location,u.current_lattitude,u.current_longitude,u.currect_location_permanent 
      FROM 
          user_master u
      LEFT JOIN 
          avatar_master a ON u.avatar_id = a.avatar_id
      WHERE 
          u.delete_flag = 0 AND u.user_type = 2 and u.role=1 order by u.user_id desc
    `;

      connection.query(userQuery, (error, userResults) => {

        if (error) {

          console.error('Error executing MySQL query:', error);

          return res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });

        }


        const users = userResults.map((user, index) => {
          const location = user.latitude ? 
              `<a href="http://www.google.com/maps/place/${user.latitude},${user.longitude}" target="_blank">
                  <span style="color:red;">${user.latitude},${user.longitude}</span>
              </a>
              <p>${user.address}</p>` :
              'NA';

              const permanent_location = user.current_lattitude ? 
              `<a href="http://www.google.com/maps/place/${user.current_lattitude},${user.current_longitude}" target="_blank">
                  <span style="color:red;">${user.current_lattitude},${user.current_longitude}</span>
              </a>
              <p>${user.current_location}</p>` :
              'NA';
              const email = user.email ? 
            user.email :
            'NA';
      
          return {
              ...user,
              sr_no: index + 1,
              status: user.active_flag === 1 ? '<span class="badge rounded-pill bg-success inv-badge">Active</span>' : '<span class="badge rounded-pill bg-danger inv-badge">Deactive</span>',
              createtime: formatDate(user.createtime),
              action_html: `<div class="btn-group">
              <a class="dropdown-item edit-btn" href="view_vip_user.html?id=${encodeUserId(user.user_id)}"><i class="fa fa-eye"></i></a>
              <a class="dropdown-item edit-btn" onclick="btnEditUserConfirm(this)" data-id="${(user.user_id)}" data-username="${user.username}" data-name="${user.name}" data-password_new="${user.password_new}" data-email="${user.email}" data-mobile="${user.mobile}" data-role="${user.role}" data-image="${user.image}" data-account_currency="${user.account_currency}" data-account_fund_balance="${user.account_fund_balance}" data-note_by_admin="${user.note_by_admin}" data-active_flag="${user.active_flag}" data-bio="${user.about}" data-address="${user.current_location}" data-latitude="${user.current_lattitude}" data-longitude="${user.current_longitude}" data-current_location="${user.current_location}" data-currect_location_permanent="${user.currect_location_permanent}">
              <i class="fa fa-edit"></i></a>

              <a class="dropdown-item edit-btn" href="javascript:void(0)" data-user-status="${user.active_flag}" data-id="${user.user_id}" onclick="btnUserActiveDeactiveConfirm(this)"><i class="fas fa-toggle-on"></i></a>
              <a class="dropdown-item edit-btn" href="javascript:void(0)"  data-id="${user.user_id}" onclick="btnUserDeleteConfirm(this)"><i class="fas fa-trash"></i></a>

            </div>`,
              image_html : `<img  width="50px" src="../server/webservice/images/${user.image}" class="rounded-circle circle-border m-b-md img-fix img-responsive" name="profile_image" id="previewholder" style="width: 70px; height: 70px;" onerror="this.src='assets/images/placeholder.png';">`,
              location: location,
              permanent_location: user.currect_location_permanent===1 ? permanent_location : 'Null',
              email: email,
          };
        });

        const record = { success: true, msg: languageMessages.msgDataFound[0], data: { users } };

        res.json(record);

      });

    } catch (error) {

      console.error('Error executing MySQL query:', error);

      res.status(500).json({ success: false, msg: languageMessages.internalServerError[0] });

    }

  });



  return router;

};



module.exports = initController;

